@@ -17,26 +17,26 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 classdef ClassificationDiscriminant
-## -*- texinfo -*-
-## @deftp {statistics} ClassificationDiscriminant
-##
-## Discriminant analysis classification
-##
-## The @code{ClassificationDiscriminant} class implements a linear discriminant
-## analysis classifier object, which can predict responses for new data using
-## the @code{predict} method.
-##
-## Discriminant analysis classification is a statistical method used to classify
-## observations into predefined groups based on their characteristics.  It
-## estimates the parameters of different distributions for each class and
-## predicts the class of new observations by finding the one with the smallest
-## misclassification cost.
-##
-## Create a @code{ClassificationDiscriminant} object by using the
-## @code{fitcdiscr} function or the class constructor.
-##
-## @seealso{fitcdiscr}
-## @end deftp
+  ## -*- texinfo -*-
+  ## @deftp {statistics} ClassificationDiscriminant
+  ##
+  ## Discriminant analysis classification
+  ##
+  ## The @code{ClassificationDiscriminant} class implements a linear
+  ## discriminant analysis classifier object, which can predict responses for
+  ## new data using the @code{predict} method.
+  ##
+  ## Discriminant analysis classification is a statistical method used to
+  ## classify observations into predefined groups based on their
+  ## characteristics.  It estimates the parameters of different distributions
+  ## for each class and predicts the class of new observations by finding the
+  ## one with the smallest misclassification cost.
+  ##
+  ## Create a @code{ClassificationDiscriminant} object by using the
+  ## @code{fitcdiscr} function or the class constructor.
+  ##
+  ## @seealso{fitcdiscr}
+  ## @end deftp
 
   properties (Access = public)
     ## -*- texinfo -*-
@@ -44,7 +44,7 @@ classdef ClassificationDiscriminant
     ##
     ## Predictor data
     ##
-    ## A numerix matrix containing the unstandardized predictor data.  Each
+    ## A numeric matrix containing the unstandardized predictor data.  Each
     ## column of @var{X} represents one predictor (variable), and each row
     ## represents one observation.  This property is read-only.
     ##
@@ -56,9 +56,10 @@ classdef ClassificationDiscriminant
     ##
     ## Class labels
     ##
-    ## Specified as a logical or numeric vector, or cell array of character
-    ## vectors.  Each value in @var{Y} is the observed class label for the
-    ## corresponding row in @var{X}.  This property is read-only.
+    ## Specified as a logical or numeric column vector, or as a character array
+    ## or a cell array of character vectors with the same number of rows as the
+    ## predictor data.  Each row in @var{Y} is the observed class label for
+    ## the corresponding row in @var{X}.  This property is read-only.
     ##
     ## @end deftp
     Y = [];
@@ -106,7 +107,7 @@ classdef ClassificationDiscriminant
     ## Names of predictor variables
     ##
     ## A cell array of character vectors specifying the names of the predictor
-    ## variables.  The names are in the order in which the appear in the
+    ## variables.  The names are in the order in which they appear in the
     ## training dataset.  This property is read-only.
     ##
     ## @end deftp
@@ -158,7 +159,7 @@ classdef ClassificationDiscriminant
     ## @qcode{Cost(i,j) = 0} if @qcode{i = j}.  In other words, the cost is 0
     ## for correct classification and 1 for incorrect classification.
     ##
-    ## Add or change the @qcode{Cost} using dot notation as in:
+    ## Add or change the @qcode{Cost} property using dot notation as in:
     ## @itemize
     ## @item @qcode{@var{obj}.Cost = @var{costMatrix}}
     ## @end itemize
@@ -175,7 +176,7 @@ classdef ClassificationDiscriminant
     ## order of the elements in @qcode{Prior} corresponds to the order of the
     ## classes in @qcode{ClassNames}.
     ##
-    ## Add or change the @qcode{Prior} using dot notation as in:
+    ## Add or change the @qcode{Prior} property using dot notation as in:
     ## @itemize
     ## @item @qcode{@var{obj}.Prior = @var{priorVector}}
     ## @end itemize
@@ -188,31 +189,37 @@ classdef ClassificationDiscriminant
     ##
     ## Transformation function for classification scores
     ##
-    ## Specified as a character vector representing a built-in function or as a
-    ## function handle for transforming the classification scores.  The
-    ## following built-in functions are supported:
+    ## Specified as a function handle for transforming the classification
+    ## scores.  Add or change the @qcode{ScoreTransform} property using dot
+    ## notation as in:
     ##
     ## @itemize
-    ## @item @qcode{'doublelogit'}
-    ## @item @qcode{'invlogit'}
-    ## @item @qcode{'ismax'}
-    ## @item @qcode{'logit'}
-    ## @item @qcode{'none'}
-    ## @item @qcode{'identity'}
-    ## @item @qcode{'sign'}
-    ## @item @qcode{'symmetric'}
-    ## @item @qcode{'symmetricismax'}
-    ## @item @qcode{'symmetriclogit'}
-    ## @end itemize
-    ##
-    ## Add or change the @qcode{ScoreTransform} using dot notation as in:
-    ## @itemize
     ## @item @qcode{@var{obj}.ScoreTransform = 'function_name'}
-    ## @item @qcode{@var{obj}.ScoreTransform = @function_handle}
+    ## @item @qcode{@var{obj}.ScoreTransform = @@function_handle}
     ## @end itemize
     ##
+    ## When specified as a character vector, it can be any of the following
+    ## built-in functions.  Nevertheless, the @qcode{ScoreTransform} property
+    ## always stores their function handle equivalent.
+    ##
+    ## @multitable @columnfractions 0.2 0.05 0.75
+    ## @headitem @var{Value} @tab @tab @var{Description}
+    ## @item @qcode{"doublelogit"} @tab @tab @math{1 ./ (1 + exp (-2 * x))}
+    ## @item @qcode{"invlogit"} @tab @tab @math{log (x ./ (1 - x))}
+    ## @item @qcode{"ismax"} @tab @tab Sets the score for the class with the
+    ## largest score to 1, and for all other classes to 0
+    ## @item @qcode{"logit"} @tab @tab @math{1 ./ (1 + exp (-x))}
+    ## @item @qcode{"none"} @tab @tab @math{x} (no transformation)
+    ## @item @qcode{"identity"} @tab @tab @math{x} (no transformation)
+    ## @item @qcode{"sign"} @tab @tab @math{-1 for x < 0, 0 for x = 0, 1 for x > 0}
+    ## @item @qcode{"symmetric"} @tab @tab @math{2 * x - 1}
+    ## @item @qcode{"symmetricismax"} @tab @tab Sets the score for the class
+    ## with the largest score to 1, and for all other classes to -1
+    ## @item @qcode{"symmetriclogit"} @tab @tab @math{2 ./ (1 + exp (-x)) - 1}
+    ## @end multitable
+    ##
     ## @end deftp
-    ScoreTransform  = [];
+    ScoreTransform  = @(x) x;
 
     ## -*- texinfo -*-
     ## @deftp {ClassificationDiscriminant} {property} Sigma
@@ -232,7 +239,7 @@ classdef ClassificationDiscriminant
     ##
     ## Class means
     ##
-    ## A @math {KxP} numeric matrix specifying the mean of the multivariate
+    ## A @math{KxP} numeric matrix specifying the mean of the multivariate
     ## normal distribution of each corresponding class, where @math{K} is the
     ## number of classes and @math{P} is the number of predictors in @var{X}.
     ## This property is read-only.
@@ -245,7 +252,7 @@ classdef ClassificationDiscriminant
     ##
     ## Coefficient matrices
     ##
-    ## A @math {KxK} structure containing the coeeficient matrices, where
+    ## A @math{KxK} structure containing the coefficient matrices, where
     ## @math{K} is the number of classes.  If the @qcode{'FillCoeffs'} parameter
     ## was set to @qcode{'off'} in either the @code{fitcdiscr} function or the
     ## @code{ClassificationDiscriminant} constructor, then @qcode{Coeffs} is
@@ -315,6 +322,8 @@ classdef ClassificationDiscriminant
     ## -*- texinfo -*-
     ## @deftp {ClassificationDiscriminant} {property} LogDetSigma
     ##
+    ## Logarithm of the determinant of the within-class covariance matrix
+    ##
     ## A scalar value specifying the logarithm of the determinant of the
     ## within-class covariance matrix.  This property is read-only.
     ##
@@ -324,12 +333,17 @@ classdef ClassificationDiscriminant
     ## -*- texinfo -*-
     ## @deftp {ClassificationDiscriminant} {property} XCentered
     ##
+    ## Predictor data with class means subtracted
+    ##
     ## A matrix of the same size as @var{X} and the values in @var{X} with the
     ## corresponding class means subtracted.  This property is read-only.
     ##
     ## @end deftp
     XCentered       = [];
+  endproperties
 
+  properties (Access = private, Hidden)
+    STname = 'none';
   endproperties
 
   methods (Hidden)
@@ -362,7 +376,7 @@ classdef ClassificationDiscriminant
         str = sprintf (str, this.ClassNames);
       endif
       fprintf ("%+25s: %s\n", 'ClassNames', str);
-      fprintf ("%+25s: '%s'\n", 'ScoreTransform', this.ScoreTransform);
+      fprintf ("%+25s: '%s'\n", 'ScoreTransform', this.STname);
       fprintf ("%+25s: %d\n", 'NumObservations', this.NumObservations);
       fprintf ("%+25s: %d\n", 'NumPredictors', this.NumPredictors);
       fprintf ("%+25s: '%s'\n", 'DiscrimType', this.DiscrimType);
@@ -425,7 +439,8 @@ classdef ClassificationDiscriminant
               this.Prior = setPrior (this, val);
             case 'ScoreTransform'
               name = "ClassificationDiscriminant";
-              this.ScoreTransform = parseScoreTransform (val, name);
+              [this.ScoreTransform, this.STname] = parseScoreTransform ...
+                                                   (varargin{2}, name);
             otherwise
               error (strcat ("ClassificationDiscriminant.subsasgn:", ...
                              " unrecognized or read-only property: '%s'"), ...
@@ -437,6 +452,7 @@ classdef ClassificationDiscriminant
   endmethods
 
   methods (Access = public)
+
     ## -*- texinfo -*-
     ## @deftypefn  {statistics} {@var{obj} =} ClassificationDiscriminant (@var{X}, @var{Y})
     ## @deftypefnx {statistics} {@var{obj} =} ClassificationDiscriminant (@dots{}, @var{name}, @var{value})
@@ -452,18 +468,18 @@ classdef ClassificationDiscriminant
     ## @item
     ## @code{X} must be a @math{NxP} numeric matrix of input data where rows
     ## correspond to observations and columns correspond to features or
-    ## variables.
-    ## @var{X} will be used to train the discriminant model.
+    ## variables.  @var{X} will be used to train the discriminant model.
     ## @item
     ## @code{Y} is @math{Nx1} matrix or cell matrix containing the class labels
-    ## of corresponding predictor data in @var{X}. @var{Y} can contain any type
+    ## of corresponding predictor data in @var{X}.  @var{Y} can contain any type
     ## of categorical data. @var{Y} must have the same number of rows as
     ## @var{X}.
     ## @end itemize
     ##
     ## @code{@var{obj} = ClassificationDiscriminant (@dots{}, @var{name},
     ## @var{value})} returns a ClassificationDiscriminant object with parameters
-    ## specified by the following@qcode{@var{name}, @var{value}} pair arguments:
+    ## specified by the following @qcode{@var{name}, @var{value}} paired input
+    ## arguments:
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
     ## @headitem @var{Name} @tab @tab @var{Value}
@@ -479,13 +495,6 @@ classdef ClassificationDiscriminant
     ## labels, @var{Y}, used for fitting the Discriminant model.
     ## @qcode{ClassNames} are of the same type as the class labels in @var{Y}.
     ##
-    ## @item @qcode{'Prior'} @tab @tab A numeric vector specifying the prior
-    ## probabilities for each class.  The order of the elements in @qcode{Prior}
-    ## corresponds to the order of the classes in @qcode{ClassNames}.
-    ## Alternatively, you can specify @qcode{"empirical"} to use the empirical
-    ## class probabilities or @qcode{"uniform"} to assume equal class
-    ## probabilities.
-    ##
     ## @item @qcode{'Cost'} @tab @tab An @math{NxR} numeric matrix containing
     ## misclassification cost for the corresponding instances in @var{X}, where
     ## @math{R} is the number of unique categories in @var{Y}.  If an instance
@@ -494,6 +503,21 @@ classdef ClassificationDiscriminant
     ## @code{@var{Mdl}.cost = somecost}.  By default, its value is
     ## @qcode{@var{cost} = ones (rows (X), numel (unique (Y)))}.
     ##
+    ## @item @qcode{'Prior'} @tab @tab A numeric vector specifying the prior
+    ## probabilities for each class.  The order of the elements in @qcode{Prior}
+    ## corresponds to the order of the classes in @qcode{ClassNames}.
+    ## Alternatively, you can specify @qcode{"empirical"} to use the empirical
+    ## class probabilities or @qcode{"uniform"} to assume equal class
+    ## probabilities.
+    ##
+    ## @item @qcode{'ScoreTransform'} @tab @tab A user-defined function handle
+    ## or a character vector specifying one of the following builtin functions
+    ## specifying the transformation applied to predicted classification scores.
+    ## Supported values include @qcode{'doublelogit'}, @qcode{'invlogit'},
+    ## @qcode{'ismax'}, @qcode{'logit'}, @qcode{'none'}, @qcode{'identity'},
+    ## @qcode{'sign'}, @qcode{'symmetric'}, @qcode{'symmetricismax'}, and
+    ## @qcode{'symmetriclogit'}.
+    ##
     ## @item @qcode{'DiscrimType'} @tab @tab A character vector or string scalar
     ## specifying the type of discriminant analysis to perform. The only
     ## supported value is @qcode{'linear'}.
@@ -543,17 +567,16 @@ classdef ClassificationDiscriminant
       [gY, gnY, glY] = grp2idx (Y);
 
       ## Set default values before parsing optional parameters
-      ClassNames           = [];
-      Cost                 = [];
-      DiscrimType          = "linear";
-      Gamma                = 0;
-      Delta                = 0;
-      NumPredictors        = [];
-      PredictorNames       = {};
-      ResponseName         = 'Y';
-      Prior                = "empirical";
-      FillCoeffs           = "on";
-      this.ScoreTransform  = 'none';
+      ClassNames     = [];
+      Cost           = [];
+      DiscrimType    = "linear";
+      Gamma          = 0;
+      Delta          = 0;
+      NumPredictors  = [];
+      PredictorNames = {};
+      ResponseName   = 'Y';
+      Prior          = "empirical";
+      FillCoeffs     = "on";
 
       ## Parse optional parameters
       while (numel (varargin) > 0)
@@ -618,7 +641,8 @@ classdef ClassificationDiscriminant
 
           case "scoretransform"
             name = "ClassificationDiscriminant";
-            this.ScoreTransform = parseScoreTransform (varargin{2}, name);
+            [this.ScoreTransform, this.STname] = parseScoreTransform ...
+                                                 (varargin{2}, name);
 
           case "discrimtype"
             DiscrimType = tolower (varargin{2});
@@ -678,7 +702,7 @@ classdef ClassificationDiscriminant
 
       ## Remove missing values from X and Y
       RowsUsed  = ! logical (sum (isnan ([X, gY]), 2));
-      Y         = Y (RowsUsed);
+      Y         = Y (RowsUsed, :);
       X         = X (RowsUsed, :);
 
       ## Renew groups in Y, get classes ordered, keep the same type
@@ -691,7 +715,7 @@ classdef ClassificationDiscriminant
 
       ## Assign the number of observations and their corresponding indices
       ## on the original data, which will be used for training the model,
-      ## to the ClassificationNeuralNetwork object
+      ## to the ClassificationDiscriminant object
       this.NumObservations = sum (RowsUsed);
       this.RowsUsed = RowsUsed;
 
@@ -1335,7 +1359,11 @@ classdef ClassificationDiscriminant
       endif
 
       ## Add default values
-      numFolds    = 10;
+      if (this.NumObservations < 10)
+        numFolds  = this.NumObservations;
+      else
+        numFolds  = 10;
+      endif
       Holdout     = [];
       Leaveout    = 'off';
       CVPartition = [];
@@ -1452,13 +1480,14 @@ classdef ClassificationDiscriminant
       MinGamma        = this.MinGamma;
       LogDetSigma     = this.LogDetSigma;
       XCentered       = this.XCentered;
+      STname          = this.STname;
 
       ## Save classdef name and all model properties as individual variables
       save ("-binary", fname, "classdef_name", "X", "Y", "NumObservations", ...
             "RowsUsed", "NumPredictors", "PredictorNames", "ResponseName", ...
             "ClassNames", "ScoreTransform", "Prior", "Cost", "Sigma", "Mu", ...
             "Coeffs", "Delta", "DiscrimType", "Gamma", "MinGamma", ...
-            "LogDetSigma", "XCentered");
+            "LogDetSigma", "XCentered", "STname");
     endfunction
 
   endmethods
@@ -1501,7 +1530,6 @@ classdef ClassificationDiscriminant
         endif
         this.Cost = Cost;
       endif
-
     endfunction
 
     function this = setPrior (this, Prior, gnY = [], gY = [])
@@ -1525,7 +1553,6 @@ classdef ClassificationDiscriminant
         endif
         this.Prior = Prior ./ sum (Prior);
       endif
-
       ## Recalculate the Const field in the Coeffs structure
       if (! isempty (this.Coeffs))
         num_classes = rows (this.ClassNames);
@@ -1859,33 +1886,53 @@ endclassdef
 %! y = species;
 %! obj = fitcdiscr (x, y, "gamma", 0.4);
 %!test
+%! status = warning;
+%! warning ('off');
+%! rand ("seed", 23);
 %! CVMdl = crossval (obj);
+%! warning (status);
 %! assert (class (CVMdl), "ClassificationPartitionedModel")
 %! assert ({CVMdl.X, CVMdl.Y}, {x, y})
 %! assert (CVMdl.KFold == 10)
 %! assert (class (CVMdl.Trained{1}), "CompactClassificationDiscriminant")
 %! assert (CVMdl.CrossValidatedModel, "ClassificationDiscriminant")
 %!test
+%! status = warning;
+%! warning ('off');
+%! rand ("seed", 23);
 %! CVMdl = crossval (obj, "KFold", 3);
+%! warning (status);
 %! assert (class (CVMdl), "ClassificationPartitionedModel")
 %! assert ({CVMdl.X, CVMdl.Y}, {x, y})
 %! assert (CVMdl.KFold == 3)
 %! assert (class (CVMdl.Trained{1}), "CompactClassificationDiscriminant")
 %! assert (CVMdl.CrossValidatedModel, "ClassificationDiscriminant")
 %!test
+%! status = warning;
+%! warning ('off');
+%! rand ("seed", 23);
 %! CVMdl = crossval (obj, "HoldOut", 0.2);
+%! warning (status);
 %! assert (class (CVMdl), "ClassificationPartitionedModel")
 %! assert ({CVMdl.X, CVMdl.Y}, {x, y})
 %! assert (class (CVMdl.Trained{1}), "CompactClassificationDiscriminant")
 %! assert (CVMdl.CrossValidatedModel, "ClassificationDiscriminant")
 %!test
+%! status = warning;
+%! warning ('off');
+%! rand ("seed", 23);
 %! CVMdl = crossval (obj, "LeaveOut", 'on');
+%! warning (status);
 %! assert (class (CVMdl), "ClassificationPartitionedModel")
 %! assert ({CVMdl.X, CVMdl.Y}, {x, y})
 %! assert (class (CVMdl.Trained{1}), "CompactClassificationDiscriminant")
 %! assert (CVMdl.CrossValidatedModel, "ClassificationDiscriminant")
 %!test
+%! status = warning;
+%! warning ('off');
+%! rand ("seed", 23);
 %! partition = cvpartition (y, 'KFold', 3);
+%! warning (status);
 %! CVMdl = crossval (obj, 'cvPartition', partition);
 %! assert (class (CVMdl), "ClassificationPartitionedModel")
 %! assert (CVMdl.KFold == 3)
