@@ -17,25 +17,25 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 classdef ClassificationNeuralNetwork
-## -*- texinfo -*-
-## @deftp {statistics} ClassificationNeuralNetwork
-##
-## Neural network classification
-##
-## The @code{ClassificationNeuralNetwork} class implements a neural network
-## classifier object, which can predict responses for new data using the
-## @code{predict} method.
-##
-## Neural network classification is a machine learning method that uses
-## interconnected nodes in multiple layers to learn complex patterns in data.
-## It processes inputs through hidden layers with activation functions to
-## produce classification outputs.
-##
-## Create a @code{ClassificationNeuralNetwork} object by using the
-## @code{fitcnet} function or the class constructor.
-##
-## @seealso{fitcnet}
-## @end deftp
+  ## -*- texinfo -*-
+  ## @deftp {statistics} ClassificationNeuralNetwork
+  ##
+  ## Neural network classification
+  ##
+  ## The @code{ClassificationNeuralNetwork} class implements a neural network
+  ## classifier object, which can predict responses for new data using the
+  ## @code{predict} method.
+  ##
+  ## Neural network classification is a machine learning method that uses
+  ## interconnected nodes in multiple layers to learn complex patterns in data.
+  ## It processes inputs through hidden layers with activation functions to
+  ## produce classification outputs.
+  ##
+  ## Create a @code{ClassificationNeuralNetwork} object by using the
+  ## @code{fitcnet} function or the class constructor.
+  ##
+  ## @seealso{fitcnet}
+  ## @end deftp
 
   properties (Access = public)
     ## -*- texinfo -*-
@@ -106,7 +106,7 @@ classdef ClassificationNeuralNetwork
     ## Names of predictor variables
     ##
     ## A cell array of character vectors specifying the names of the predictor
-    ## variables.  The names are in the order in which the appear in the
+    ## variables.  The names are in the order in which they appear in the
     ## training dataset.  This property is read-only.
     ##
     ## @end deftp
@@ -157,23 +157,23 @@ classdef ClassificationNeuralNetwork
     ## @end itemize
     ##
     ## When specified as a character vector, it can be any of the following
-    ## built-in functions.  Nevertherless, the @qcode{ScoreTransform} property
+    ## built-in functions.  Nevertheless, the @qcode{ScoreTransform} property
     ## always stores their function handle equivalent.
     ##
     ## @multitable @columnfractions 0.2 0.05 0.75
     ## @headitem @var{Value} @tab @tab @var{Description}
-    ## @item @qcode{"doublelogit"} @tab @tab @math{1 ./ (1 + exp .^ (-2 * x))}
-    ## @item @qcode{"invlogit"} @tab @tab @math{log (x ./ (1 - x))}
+    ## @item @qcode{"doublelogit"} @tab @tab @math{1 ./ (1 + exp (-2 * x))}
+    ## @item @qcode{"invlogit"} @tab @tab @math{1 ./ (1 + exp (-x))}
     ## @item @qcode{"ismax"} @tab @tab Sets the score for the class with the
     ## largest score to 1, and for all other classes to 0
-    ## @item @qcode{"logit"} @tab @tab @math{1 ./ (1 + exp .^ (-x))}
+    ## @item @qcode{"logit"} @tab @tab @math{log (x ./ (1 - x))}
     ## @item @qcode{"none"} @tab @tab @math{x} (no transformation)
     ## @item @qcode{"identity"} @tab @tab @math{x} (no transformation)
     ## @item @qcode{"sign"} @tab @tab @math{-1 for x < 0, 0 for x = 0, 1 for x > 0}
-    ## @item @qcode{"symmetric"} @tab @tab @math{2 * x + 1}
+    ## @item @qcode{"symmetric"} @tab @tab @math{2 * x - 1}
     ## @item @qcode{"symmetricismax"} @tab @tab Sets the score for the class
     ## with the largest score to 1, and for all other classes to -1
-    ## @item @qcode{"symmetriclogit"} @tab @tab @math{2 ./ (1 + exp .^ (-x)) - 1}
+    ## @item @qcode{"symmetriclogit"} @tab @tab @math{2 ./ (1 + exp (-x)) - 1}
     ## @end multitable
     ##
     ## @end deftp
