@@ -17,29 +17,29 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 classdef CompactClassificationDiscriminant
-## -*- texinfo -*-
-## @deftp {statistics} CompactClassificationDiscriminant
-##
-## Compact discriminant analysis classification
-##
-## The @code{CompactClassificationDiscriminant} class implements a compact
-## version of a linear discriminant analysis classifier object, which can
-## predict responses for new data using the @code{predict} method but does not
-## store the training data.
-##
-## A @code{CompactClassificationDiscriminant} object is a compact version of a
-## discriminant analysis model, @code{ClassificationDiscriminant}.  It does not
-## include the training data resulting in a smaller classifier size, which can
-## be used for making predictions from new data, but not for tasks such as
-## cross validation.  It can only be created from a
-## @code{ClassificationDiscriminant} model by using the @code{compact} object
-## method.
-##
-## Create a @code{CompactClassificationDiscriminant} object by using the
-## @code{compact} method of a @code{ClassificationDiscriminant} object.
-##
-## @seealso{fitcdiscr, ClassificationDiscriminant}
-## @end deftp
+  ## -*- texinfo -*-
+  ## @deftp {statistics} CompactClassificationDiscriminant
+  ##
+  ## Compact discriminant analysis classification
+  ##
+  ## The @code{CompactClassificationDiscriminant} class implements a compact
+  ## version of a linear discriminant analysis classifier object, which can
+  ## predict responses for new data using the @code{predict} method but does not
+  ## store the training data.
+  ##
+  ## A @code{CompactClassificationDiscriminant} object is a compact version of a
+  ## discriminant analysis model, @code{ClassificationDiscriminant}.  It does
+  ## not include the training data resulting in a smaller classifier size, which
+  ## can be used for making predictions from new data, but not for tasks such as
+  ## cross validation.  It can only be created from a
+  ## @code{ClassificationDiscriminant} model by using the @code{compact} object
+  ## method.
+  ##
+  ## Create a @code{CompactClassificationDiscriminant} object by using the
+  ## @code{compact} method of a @code{ClassificationDiscriminant} object.
+  ##
+  ## @seealso{fitcdiscr, ClassificationDiscriminant}
+  ## @end deftp
 
   properties (Access = public)
     ## -*- texinfo -*-
@@ -60,7 +60,7 @@ classdef CompactClassificationDiscriminant
     ## Names of predictor variables
     ##
     ## A cell array of character vectors specifying the names of the predictor
-    ## variables.  The names are in the order in which the appear in the
+    ## variables.  The names are in the order in which they appear in the
     ## training dataset.  This property is read-only.
     ##
     ## @end deftp
@@ -140,23 +140,23 @@ classdef CompactClassificationDiscriminant
     ## scores.  This property is read-only.
     ##
     ## When specified as a character vector, it can be any of the following
-    ## built-in functions.  Nevertherless, the @qcode{ScoreTransform} property
+    ## built-in functions.  Nevertheless, the @qcode{ScoreTransform} property
     ## always stores their function handle equivalent.
     ##
     ## @multitable @columnfractions 0.2 0.05 0.75
     ## @headitem @var{Value} @tab @tab @var{Description}
-    ## @item @qcode{"doublelogit"} @tab @tab @math{1 ./ (1 + exp .^ (-2 * x))}
+    ## @item @qcode{"doublelogit"} @tab @tab @math{1 ./ (1 + exp (-2 * x))}
     ## @item @qcode{"invlogit"} @tab @tab @math{log (x ./ (1 - x))}
     ## @item @qcode{"ismax"} @tab @tab Sets the score for the class with the
     ## largest score to 1, and for all other classes to 0
-    ## @item @qcode{"logit"} @tab @tab @math{1 ./ (1 + exp .^ (-x))}
+    ## @item @qcode{"logit"} @tab @tab @math{1 ./ (1 + exp (-x))}
     ## @item @qcode{"none"} @tab @tab @math{x} (no transformation)
     ## @item @qcode{"identity"} @tab @tab @math{x} (no transformation)
     ## @item @qcode{"sign"} @tab @tab @math{-1 for x < 0, 0 for x = 0, 1 for x > 0}
-    ## @item @qcode{"symmetric"} @tab @tab @math{2 * x + 1}
+    ## @item @qcode{"symmetric"} @tab @tab @math{2 * x - 1}
     ## @item @qcode{"symmetricismax"} @tab @tab Sets the score for the class
     ## with the largest score to 1, and for all other classes to -1
-    ## @item @qcode{"symmetriclogit"} @tab @tab @math{2 ./ (1 + exp .^ (-x)) - 1}
+    ## @item @qcode{"symmetriclogit"} @tab @tab @math{2 ./ (1 + exp (-x)) - 1}
     ## @end multitable
     ##
     ## @end deftp
@@ -192,7 +192,7 @@ classdef CompactClassificationDiscriminant
     ##
     ## Coefficient matrices
     ##
-    ## A @math {KxK} structure containing the coeeficient matrices, where
+    ## A @math{KxK} structure containing the coefficient matrices, where
     ## @math{K} is the number of classes.  If the @qcode{'FillCoeffs'} parameter
     ## was set to @qcode{'off'} in the original @code{ClassificationDiscriminant}
     ## model, then @qcode{Coeffs} is empty @qcode{([])}.  This property is
