@@ -17,32 +17,27 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 classdef DaviesBouldinEvaluation < ClusterCriterion
-  ## -*- texinfo -*-
-  ## @deftypefn {Function File} {@var{obj} =} evalclusters (@var{x}, @var{clust}, @qcode{DaviesBouldin})
-  ## @deftypefnx {Function File} {@var{obj} =} evalclusters (@dots{}, @qcode{Name}, @qcode{Value})
-  ##
-  ## A Davies-Bouldin object to evaluate clustering solutions.
-  ##
-  ## A @code{DaviesBouldinEvaluation} object is a @code{ClusterCriterion}
-  ## object used to evaluate clustering solutions using the Davies-Bouldin
-  ## criterion.
-  ##
-  ## The Davies-Bouldin criterion is based on the ratio between the distances
-  ## between clusters and within clusters, that is the distances between the
-  ## centroids and the distances between each datapoint and its centroid.
-  ##
-  ## The best solution according to the Davies-Bouldin criterion is the one
-  ## that scores the lowest value.
-  ##
-  ## @seealso{evalclusters, ClusterCriterion, CalinskiHarabaszEvaluation,
-  ## GapEvaluation, SilhouetteEvaluation}
-  ## @end deftypefn
+## -*- texinfo -*-
+## @deftp {statistics} DaviesBouldinEvaluation
+##
+## Davies-Bouldin object to evaluate clustering solutions
+##
+## A @code{DaviesBouldinEvaluation} object is a @code{ClusterCriterion}
+## object used to evaluate clustering solutions using the Davies-Bouldin
+## criterion.
+##
+## The Davies-Bouldin criterion is based on the ratio between the distances
+## between clusters and within clusters — distances between centroids and
+## distances between each datapoint and its centroid.
+##
+## The best solution according to the Davies-Bouldin criterion is the one
+## that produces the lowest Davies-Bouldin value.
+##
+## @seealso{evalclusters, ClusterCriterion, CalinskiHarabaszEvaluation,
+## GapEvaluation, SilhouetteEvaluation}
+## @end deftp
 
-  properties (GetAccess = public, SetAccess = private)
-
-  endproperties
-
-  properties (Access = protected)
+  properties (Access = protected, Hidden)
     Centroids = {}; # a list of the centroids for every solution
   endproperties
 
@@ -57,9 +52,9 @@ classdef DaviesBouldinEvaluation < ClusterCriterion
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn {DaviesBouldinEvaluation} {@var{obj} =} addK (@var{obj}, @var{K})
+    ## @deftypefn  {DaviesBouldinEvaluation} {@var{obj} =} addK (@var{obj}, @var{K})
     ##
-    ## Add a new cluster array to inspect the DaviesBouldinEvaluation object.
+    ## Add new cluster numbers to inspect in the DaviesBouldinEvaluation object.
     ##
     ## @end deftypefn
     function this = addK (this, K)
@@ -86,11 +81,11 @@ classdef DaviesBouldinEvaluation < ClusterCriterion
     ## @deftypefn  {DaviesBouldinEvaluation} {} plot (@var{obj})
     ## @deftypefnx {DaviesBouldinEvaluation} {@var{h} =} plot (@var{obj})
     ##
-    ## Plot the evaluation results.
+    ## Plot Davies-Bouldin evaluation results.
     ##
     ## Plot the CriterionValues against InspectedK from the
-    ## DaviesBouldinEvaluation ClusterCriterion, @var{obj}, to the current plot.
-    ## It can also return a handle to the current plot.
+    ## DaviesBouldinEvaluation ClusterCriterion to the current plot.
+    ## Returns an axes handle if requested.
     ##
     ## @end deftypefn
     function h = plot (this)
@@ -105,14 +100,14 @@ classdef DaviesBouldinEvaluation < ClusterCriterion
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn {DaviesBouldinEvaluation} {@var{obj} =} compact (@var{obj})
+    ## @deftypefn  {DaviesBouldinEvaluation} {@var{obj} =} compact (@var{obj})
     ##
-    ## Return a compact DaviesBouldinEvaluation object (not implemented yet).
+    ## Return a compact DaviesBouldinEvaluation object (not implemented).
     ##
     ## @end deftypefn
     function this = compact (this)
-      warning (["DaviesBouldinEvaluation.compact: this"...
-                " method is not yet implemented."]);
+      warning (strcat ("DaviesBouldinEvaluation.compact:", ...
+                       " this method is not yet implemented."));
     endfunction
 
   endmethods
@@ -146,8 +141,8 @@ classdef DaviesBouldinEvaluation < ClusterCriterion
                       length (ClusteringSolution) == this.NumObservations)
                 this.ClusteringSolutions(:, iter) = ClusteringSolution';
               else
-                error (["DaviesBouldinEvaluation: invalid return value "...
-                        "from custom clustering function"]);
+                error (strcat ("DaviesBouldinEvaluation: invalid return", ...
+                               " value from custom clustering function."));
               endif
               this.ClusteringSolutions(:, iter) = ...
                 this.ClusteringFunction(UsableX, this.InspectedK(iter));
@@ -173,8 +168,8 @@ classdef DaviesBouldinEvaluation < ClusterCriterion
                   this.Centroids{iter} = gmm.mu;
 
                 otherwise
-                  error (["DaviesBouldinEvaluation: unexpected error, " ...
-                          "report this bug"]);
+                  error (strcat ("DaviesBouldinEvaluation: unexpected", ...
+                                 " error, report this bug."));
               endswitch
             endif
           endif
