@@ -16,23 +16,23 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn  {statistics} @var{pval} = chi2test (@var{x})
-## @deftypefnx {statistics} [@var{pval}, @var{chisq}] = chi2test (@var{x})
-## @deftypefnx {statistics} [@var{pval}, @var{chisq}, @var{dF}] = chi2test (@var{x})
-## @deftypefnx {statistics} [@var{pval}, @var{chisq}, @var{dF}, @var{E}] = chi2test (@var{x})
-## @deftypefnx {statistics} [@dots{}] = chi2test (@var{x}, @var{name}, @var{value})
+## @deftypefn  {statistics} {@var{pval} =} chi2test (@var{x})
+## @deftypefnx {statistics} {[@var{pval}, @var{chisq}] =} chi2test (@var{x})
+## @deftypefnx {statistics} {[@var{pval}, @var{chisq}, @var{dF}] =} chi2test (@var{x})
+## @deftypefnx {statistics} {[@var{pval}, @var{chisq}, @var{dF}, @var{E}] =} chi2test (@var{x})
+## @deftypefnx {statistics} {[@dots{}] =} chi2test (@var{x}, @var{name}, @var{value})
 ##
 ## Perform a chi-squared test (for independence or homogeneity).
 ##
 ## For 2-way contingency tables, @code{chi2test} performs and a chi-squared test
 ## for independence or homogeneity, according to the sampling scheme and related
-## question.  Independence means that the the two variables forming the 2-way
+## question.  Independence means that the two variables forming the 2-way
 ## table are not associated, hence you cannot predict from one another.
 ## Homogeneity refers to the concept of similarity, hence they all come from the
 ## same distribution.
 ##
 ## Both tests are computationally identical and will produce the same result.
-## Nevertheless, they anwser to different questions.  Consider two variables,
+## Nevertheless, they answer to different questions.  Consider two variables,
 ## one for gender and another for smoking.  To test independence (whether gender
 ## and smoking is associated), we would randomly sample from the general
 ## population and break them down into categories in the table.  To test
@@ -48,7 +48,7 @@
 ## @item @tab @var{pval} @tab the p-value of the relevant test.
 ## @item @tab @var{chisq} @tab the chi^2 statistic of the relevant test.
 ## @item @tab @var{dF} @tab the degrees of freedom of the relevant test.
-## @item @tab @var{E} @tab the EXPECTED values of the original contigency table.
+## @item @tab @var{E} @tab the EXPECTED values of the original contingency table.
 ## @end multitable
 ##
 ## Unlike MATLAB, in GNU Octave @code{chi2test} also supports 3-way tables,
@@ -88,7 +88,7 @@
 ## have expected frequencies less than 5 or any cell with expected frequency
 ## less than 1.  In such cases, use @code{fishertest}.
 ##
-## @seealso{fishertest}
+## @seealso{crosstab, fishertest, mcnemar_test}
 ## @end deftypefn
 
 function [pval, chisq, df, E] = chi2test (x, varargin)
@@ -105,7 +105,7 @@ function [pval, chisq, df, E] = chi2test (x, varargin)
   if (any (isnan (x(:))))
     error ("chi2test: X must not have missing values (NaN).");
   endif
-  ## Get size and dimensions of contigency table
+  ## Get size and dimensions of contingency table
   sz = size (x);
   dim = length (sz);
   ## Check optional arguments
@@ -128,13 +128,13 @@ function [pval, chisq, df, E] = chi2test (x, varargin)
   endif
   ## Calculate total sample size
   n = sum (x(:));
-  ## For 2-way contigency table
+  ## For 2-way contingency table
   if (length (sz) == 2)
     ## Calculate degrees of freedom
     df = prod (sz - 1);
     ## Calculate expected values
     E = sum (x')' * sum (x) / n;
-  ## For 3-way contigency table
+  ## For 3-way contingency table
   elseif (length (sz) == 3)
     ## Check optional arguments
     if (nargin == 1 || strcmpi (varargin{1}, "mutual"))
@@ -294,7 +294,7 @@ function [pval, chisq, df, E] = chi2test (x, varargin)
     else
       error ("chi2test: invalid model name for testing a 3-way table.");
     endif
-  ## For k-way contigency table, where k > 3
+  ## For k-way contingency table, where k > 3
   else
     ## Calculate degrees of freedom
     df = prod (sz) - sum (sz) + 2;
