@@ -1,7 +1,8 @@
 ## Copyright (C) 1995-2017 Kurt Hornik
 ## Copyright (C) 2018 John Donoghue
 ## Copyright (C) 2021 Stefano Guidoni
-## Copyright (C) 2022 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2022-2025 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2025 Yasin Achengli
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -43,76 +44,63 @@ function [t, chisq, p, labels] = crosstab (varargin)
     print_usage ();
   endif
 
-  v_length = size (varargin{1}, 1);
-
   ## main - begin
-  v_reshape = [];                    # vector of the dimensions of t
-  X = [];                            # matrix of the indexed input values
-  labels = {};                       # cell array of labels
+  v_length = [];                    # vector of lengths of input vectors
+  reshape_format = [];              # vector of the dimensions of t
+  X = [];                           # matrix of the indexed input values
+  labels = {};                      # cell array of labels
+  coordinates = {};                 # cell array of unique elements
 
-  for i = 1 : nargin
+  for i = 1:nargin
+    vector = varargin{i};
     ## If char array, convert to numerical vector
-    try
-      [vector, gnames] = grp2idx (varargin{i});
-    catch
-      error ("crosstab: x1, x2 ... xn must be vectors.");
-    end_try_catch
-    if ((! isvector (vector)) || (v_length != length (vector)))
+    if (ischar (vector) || iscellstr (vector))
+      try
+        [vector, gnames] = grp2idx (vector);
+      catch
+        error ("crosstab: x1, x2 ... xn must be vectors.");
+      end_try_catch
+    else
+      if (! isvector (vector))
+        error ("crosstab: x1, x2 ... xn must be vectors.");
+      endif
+      vector = vector(:);
+      gnames = cellstr (num2str (vector));
+    endif
+    v_length(i) = length (vector);
+    if (length (unique (v_length)) != 1)
       error ("crosstab: x1, x2 ... xn must be vectors of the same length.");
     endif
     X = [X, vector];
-    for h = 1 : length (gnames)
-      labels{h, i} = gnames{h, 1};
+    for h = 1:length (gnames)
+      labels{h, i} = gnames{h};
     endfor
-    v_reshape(i) = length (unique (vector));
+    reshape_format(i) = length (unique (vector(!isnan (vector))));
+    coordinates(i) = unique (vector(!isnan (vector)));
   endfor
 
-  v = unique (X(:, nargin));
-  t = [];
+  t = zeros (reshape_format);
 
-  ## core logic, this employs a recursive function "crosstab_recursive"
-  ## given (x1, x2, x3, ... xn) as inputs
-  ## t(i,j,k,...) = sum (x1(:) == v1(i) & x2(:) == v2(j) & ...)
-  for i = 1 : length (v)
-    t = [t, (crosstab_recursive (nargin - 1,...
-      (X(:, nargin) == v(i) | isnan (v(i)) * isnan (X(:, nargin)))))];
-  endfor
-
-  t = reshape(t, v_reshape);         # build the nargin-dimensional matrix
-
-  ## additional statistics
-  if (length (v_reshape) > 1)
-    [p, chisq] = chi2test (t);
-  endif
-  ## main - end
-
-
-  ## function: crosstab_recursive
-  ## while there are input vectors, let's do iterations over them
-  function t_partial = crosstab_recursive (x_idx, t_parent)
-    y = X(:, x_idx);
-    w = unique (y);
-
-    t_partial = [];
-    if (x_idx == 1)
-      ## we have reached the last vector,
-      ## let the computation begin
-      for j = 1 : length (w)
-        t_partial = [t_partial, ...
-          sum(t_parent & (y == w(j) | isnan (w(j)) * isnan (y)));];
-      endfor
-    else
-      ## if there are more vectors,
-      ## just add data and pass it through to the next iteration
-      for j = 1 : length (w)
-        t_partial = [t_partial, ...
-          (crosstab_recursive (x_idx - 1, ...
-            (t_parent & (y == w(j) | isnan (w(j)) * isnan (y)))))];
+  ## Main logic:
+  ## For each combination of x1, x2, ... xn, search in unique elements stored 
+  ## in coordinates for each dimension and increment the position value in t 
+  ## multidimensional matrix (always if there is no NaN element in the combination).
+  for idx = 1:size (X, 1)
+    if (!any (isnan (X(idx,:))))
+      location = zeros (1,size (X, 2));
+      for jdx = 1:size (X,2)
+        location(jdx) = find (cell2mat (coordinates(jdx)) == X(idx, jdx));
       endfor
+      t(num2cell (location){:}) += 1;
     endif
-  endfunction
-endfunction
+  endfor
 
+  if (nargout > 1)
+    if (length (reshape_format) > 1)
+      [p, chisq] = chi2test (t);
+    endif
+  endif
+endfunction
 
 ## Test input validation
 %!error crosstab ()
@@ -131,4 +119,29 @@ endfunction
 %! [table, chisq, p, labels] = crosstab (cyl4, when, org);
 %! assert (table(2,3,2), 17);
 %! assert (labels{1,3}, "USA");
-
+%!test
+%! x = [1, 1, 2, 3, 1];
+%! y = [1, 2, 5, 3, 1];
+%! t = crosstab (x, y);
+%! assert (t, [2, 1, 0, 0; 0, 0, 0, 1; 0, 0, 1, 0]);
+%!test
+%! x = [1, 1, 2, 3, 1];
+%! y = [1, 2, 3, 5, 1];
+%! t = crosstab (x, y);
+%! assert (t, [2, 1, 0, 0; 0, 0, 1, 0; 0, 0, 0, 1]);
+%!test
+%! x1 = [1, 3, 7, 7, 8];
+%! x2 = [4, 2, 1, 1, 1];
+%! x3 = [6, 2, 6, 2, NaN];
+%! T1 = [0, 0, 0; 0, 1, 0; 1, 0, 0; 0, 0, 0];
+%! T2 = [0, 0, 1; 0, 0, 0; 1, 0, 0; 0, 0, 0];
+%! T = zeros (4, 3, 2);
+%! T(:,:,1) = T1;
+%! T(:,:,2) = T2;
+%! t = crosstab (x1, x2, x3);
+%! assert (t, T);
+%!test
+%! x = [1, 2, NaN, 1];
+%! y = [1, 2, 3, NaN];
+%! t = crosstab (x, y);
+%! assert (t, [1, 0, 0; 0, 1, 0]);
