@@ -4,7 +4,7 @@
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
-## This progrm is free software; you can redistribute it and/or modify
+## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
 ## the Free Software Foundation; either version 3 of the License, or
 ## (at your option) any later version.
