@@ -2,19 +2,18 @@
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
-## Octave is free software; you can redistribute it and/or modify it
-## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3 of the License, or (at
-## your option) any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## Octave is distributed in the hope that it will be useful, but
-## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn  {statistics} {@var{muhat} =} normfit (@var{x})
@@ -87,6 +86,9 @@
 ## @end itemize
 ## @end itemize
 ##
+## Further information about the normal distribution can be found at
+## @url{https://en.wikipedia.org/wiki/Normal_distribution}
+##
 ## @seealso{normcdf, norminv, normpdf, normrnd, normlike, normstat}
 ## @end deftypefn
 
@@ -129,6 +131,8 @@ function [muhat, sigmahat, muci, sigmaci] = normfit (x, alpha, censor, freq, opt
   ## Check frequency vector
   if (nargin < 4 || isempty (freq))
     freq = 1;
+  elseif (any (freq < 0))
+    error ("normfit: FREQ must not contain negative values.");
   elseif (isequal (size (x), size (freq)))
     n = sum (freq);
     is_zero = find (freq == 0);
@@ -213,7 +217,7 @@ function [muhat, sigmahat, muci, sigmaci] = normfit (x, alpha, censor, freq, opt
     return
   endif
 
-  ## 4. Αll uncensored observations equal and greater than all the
+  ## 4. All uncensored observations equal and greater than all the
   ## censored observations
   x_uncensored = x(censor == 0);
   range_x_uncensored = range (x_uncensored);
@@ -249,7 +253,7 @@ function [muhat, sigmahat, muci, sigmaci] = normfit (x, alpha, censor, freq, opt
   ## Optimize the parameters as doubles, regardless of input data type
   paramhat = cast (paramhat, "double");
 
-  ## Search for parameter that minimize the negative log likelihood function
+  ## Search for parameter that minimizes the negative log likelihood function
   [paramhat, ~, err, output] = fminsearch ...
                     (@(ph) norm_nlogl (ph, x, censor, freq), paramhat, options);
 
@@ -381,7 +385,7 @@ function ci = norm_ci (paramhat, cv, alpha, x, censor, freq)
 endfunction
 
 %!demo
-%! ## Sample 3 populations from 3 different normal distibutions
+%! ## Sample 3 populations from 3 different normal distributions
 %! randn ("seed", 1);    # for reproducibility
 %! r1 = normrnd (2, 5, 5000, 1);
 %! randn ("seed", 2);    # for reproducibility
@@ -421,7 +425,7 @@ endfunction
 %!                  muhat(2), sigmahat(2)), ...
 %!          sprintf("PDF for sample 3 with estimated mu=%0.2f and σ=%0.2f", ...
 %!                  muhat(3), sigmahat(3))}, "location", "northwest")
-%! title ("Three population samples from different normal distibutions")
+%! title ("Three population samples from different normal distributions")
 %! hold off
 
 ## Test output
@@ -455,4 +459,6 @@ endfunction
 %! normfit (ones (20,1), [], zeros(15,1))
 %!error<normfit: X and FREQ vectors mismatch.> ...
 %! normfit (ones (20,1), [], zeros(20,1), ones(25,1))
+%!error<normfit: FREQ must not contain negative values.> ...
+%! normfit (ones (5,1), [], zeros(5,1), [1, 2, 1, 2, -1]')
 %!error<normfit: > normfit (ones (20,1), [], zeros(20,1), ones(20,1), "options")
