@@ -1,4 +1,5 @@
-## Copyright (C) 2024 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2024-2025 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2025 Swayam Shah <swayamshah66@gmail.com>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -17,95 +18,230 @@
 
 classdef BurrDistribution
   ## -*- texinfo -*-
-  ## @deftypefn {statistics} BurrDistribution
+  ## @deftp {statistics} BurrDistribution
   ##
   ## Burr probability distribution object.
   ##
   ## A @code{BurrDistribution} object consists of parameters, a model
   ## description, and sample data for a Burr probability distribution.
   ##
-  ## The Burr distribution uses the following parameters.
-  ##
-  ## @multitable @columnfractions 0.25 0.48 0.27
-  ## @headitem @var{Parameter} @tab @var{Description} @tab @var{Support}
-  ##
-  ## @item @qcode{alpha} @tab Shape @tab @math{-Inf < alpha < Inf}
-  ## @item @qcode{c} @tab Scale @tab @math{c > 0}
-  ## @item @qcode{k} @tab Location @tab @math{-Inf < k < Inf}
-  ## @end multitable
+  ## The Burr distribution is a continuous probability distribution that models
+  ## a non-negative random variable, commonly used to model household income.
+  ## It is defined by a scale parameter @var{alpha} and two shape parameters
+  ## @var{c} and @var{k}.
   ##
   ## There are several ways to create a @code{BurrDistribution} object.
   ##
   ## @itemize
   ## @item Fit a distribution to data using the @code{fitdist} function.
-  ## @item Create a distribution with specified parameter values using the
+  ## @item Create a distribution with fixed parameter values using the
   ## @code{makedist} function.
-  ## @item Use the constructor @qcode{BurrDistribution (@var{alpha}, @var{c})}
-  ## to create a generalized extreme value distribution
-  ## with specified parameter values.
-  ## @item Use the static method @qcode{BurrDistribution.fit
-  ## (@var{x}, @var{alpha}, @var{freq})} to a distribution to data @var{x}.
+  ## @item Use the constructor @qcode{BurrDistribution (@var{alpha}, @var{c},
+  ## @var{k})} to create a Burr distribution with fixed parameter values
+  ## @var{alpha}, @var{c}, and @var{k}.
+  ## @item Use the static method @qcode{BurrDistribution.fit (@var{x},
+  ## @var{alpha}, @var{censor}, @var{freq}, @var{options})} to fit a
+  ## distribution to the data in @var{x} using the same input arguments as the
+  ## @code{burrfit} function.
   ## @end itemize
   ##
   ## It is highly recommended to use @code{fitdist} and @code{makedist}
-  ## functions to create probability distribution objects, instead of the
-  ## constructor and the aforementioned static method.
-  ##
-  ## A @code{BurrDistribution} object contains the following
-  ## properties, which can be accessed using dot notation.
-  ##
-  ## @multitable @columnfractions 0.25 0.25 0.25 0.25
-  ## @item @qcode{DistributionName} @tab @qcode{DistributionCode} @tab
-  ## @qcode{NumParameters} @tab @qcode{ParameterNames}
-  ## @item @qcode{ParameterDescription} @tab @qcode{ParameterValues} @tab
-  ## @qcode{ParameterValues} @tab @qcode{ParameterCI}
-  ## @item @qcode{ParameterIsFixed} @tab @qcode{Truncation} @tab
-  ## @qcode{IsTruncated} @tab @qcode{InputData}
-  ## @end multitable
-  ##
-  ## A @code{BurrDistribution} object contains the following
-  ## methods:
-  ## @code{cdf}, @code{icdf}, @code{iqr}, @code{mean}, @code{median},
-  ## @code{negloglik}, @code{paramci}, @code{pdf}, @code{plot}, @code{proflik},
-  ## @code{random}, @code{std}, @code{truncate}, @code{var}.
+  ## functions to create probability distribution objects, instead of the class
+  ## constructor or the aforementioned static method.
   ##
   ## Further information about the Burr distribution can be found at
   ## @url{https://en.wikipedia.org/wiki/Burr_distribution}
   ##
   ## @seealso{fitdist, makedist, burrcdf, burrinv, burrpdf, burrrnd, burrfit,
   ## burrlike, burrstat}
-  ## @end deftypefn
+  ## @end deftp
 
   properties (Dependent = true)
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} alpha
+    ##
+    ## Scale parameter
+    ##
+    ## A positive scalar value characterizing the scale of the Burr
+    ## distribution. You can access the @qcode{alpha} property using dot name
+    ## assignment.
+    ##
+    ## @end deftp
     alpha
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} c
+    ##
+    ## First shape parameter
+    ##
+    ## A positive scalar value characterizing the first shape parameter of the
+    ## Burr distribution. You can access the @qcode{c} property using dot name
+    ## assignment.
+    ##
+    ## @end deftp
     c
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} k
+    ##
+    ## Second shape parameter
+    ##
+    ## A positive scalar value characterizing the second shape parameter of the
+    ## Burr distribution. You can access the @qcode{k} property using dot name
+    ## assignment.
+    ##
+    ## @end deftp
     k
   endproperties
 
   properties (GetAccess = public, Constant = true)
-    CensoringAllowed = false;
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} DistributionName
+    ##
+    ## Probability distribution name
+    ##
+    ## A character vector specifying the name of the probability distribution
+    ## object. This property is read-only.
+    ##
+    ## @end deftp
     DistributionName = "BurrDistribution";
-    DistributionCode = "burr";
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} NumParameters
+    ##
+    ## Number of parameters
+    ##
+    ## A scalar integer value specifying the number of parameters characterizing
+    ## the probability distribution. This property is read-only.
+    ##
+    ## @end deftp
     NumParameters = 3;
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} ParameterNames
+    ##
+    ## Names of parameters
+    ##
+    ## A @math{3x1} cell array of character vectors with each element containing
+    ## the name of a distribution parameter. This property is read-only.
+    ##
+    ## @end deftp
     ParameterNames = {"alpha", "c", "k"};
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} ParameterDescription
+    ##
+    ## Description of parameters
+    ##
+    ## A @math{3x1} cell array of character vectors with each element containing
+    ## a short description of a distribution parameter. This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterDescription = {"Scale", "1st shape", "2nd shape"};
   endproperties
 
-  properties (GetAccess = public, Constant = true)
+  properties (GetAccess = public, Constant = true, Hidden)
+    CensoringAllowed = false;
+    DistributionCode = "burr";
     ParameterRange = [realmin, realmin, realmin; Inf, Inf, Inf];
     ParameterLogCI = [false, true, false];
   endproperties
 
-  properties (GetAccess = public , SetAccess = protected)
+  properties (GetAccess = public, SetAccess = protected)
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} ParameterValues
+    ##
+    ## Distribution parameter values
+    ##
+    ## A @math{3x1} numeric vector containing the values of the distribution
+    ## parameters. This property is read-only. You can change the distribution
+    ## parameters by assigning new values to the @qcode{alpha}, @qcode{c}, and
+    ## @qcode{k} properties.
+    ##
+    ## @end deftp
     ParameterValues
-    ParameterCI
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} ParameterCovariance
+    ##
+    ## Covariance matrix of the parameter estimates
+    ##
+    ## A @math{3x3} numeric matrix containing the variance-covariance of the
+    ## parameter estimates. Diagonal elements contain the variance of each
+    ## estimated parameter, and non-diagonal elements contain the covariance
+    ## between the parameter estimates. The covariance matrix is only meaningful
+    ## when the distribution was fitted to data. If the distribution object was
+    ## created with fixed parameters, or a parameter of a fitted distribution is
+    ## modified, then all elements of the variance-covariance are zero. This
+    ## property is read-only.
+    ##
+    ## @end deftp
     ParameterCovariance
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} ParameterIsFixed
+    ##
+    ## Flag for fixed parameters
+    ##
+    ## A @math{1x3} logical vector specifying which parameters are fixed and
+    ## which are estimated. @qcode{true} values correspond to fixed parameters,
+    ## @qcode{false} values correspond to parameter estimates. This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterIsFixed
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} Truncation
+    ##
+    ## Truncation interval
+    ##
+    ## A @math{1x2} numeric vector specifying the truncation interval for the
+    ## probability distribution. First element contains the lower boundary,
+    ## second element contains the upper boundary. This property is read-only.
+    ## You can only truncate a probability distribution with the
+    ## @qcode{truncate} method.
+    ##
+    ## @end deftp
     Truncation
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} IsTruncated
+    ##
+    ## Flag for truncated probability distribution
+    ##
+    ## A logical scalar value specifying whether a probability distribution is
+    ## truncated or not. This property is read-only.
+    ##
+    ## @end deftp
     IsTruncated
+
+    ## -*- texinfo -*-
+    ## @deftp {BurrDistribution} {property} InputData
+    ##
+    ## Data used for fitting a probability distribution
+    ##
+    ## A scalar structure containing the following fields:
+    ## @itemize
+    ## @item @qcode{data}: a numeric vector containing the data used for
+    ## distribution fitting.
+    ## @item @qcode{cens}: an empty array, since @qcode{BurrDistribution} does
+    ## not allow censoring.
+    ## @item @qcode{freq}: a numeric vector of non-negative integer values
+    ## containing the frequency information corresponding to the elements of the
+    ## data used for distribution fitting. If no frequency vector was used for
+    ## distribution fitting, then this field defaults to an empty array.
+    ## @end itemize
+    ##
+    ## @end deftp
     InputData
   endproperties
 
+  properties (GetAccess = public, SetAccess = protected, Hidden)
+    ParameterCI
+  endproperties
+
   methods (Hidden)
 
     function this = BurrDistribution (alpha, c, k)
@@ -124,11 +260,11 @@ classdef BurrDistribution
 
     function display (this)
       fprintf ("%s =\n", inputname(1));
-      __disp__ (this, "normal distribution");
+      __disp__ (this, "Burr distribution");
     endfunction
 
     function disp (this)
-      __disp__ (this, "normal distribution");
+      __disp__ (this, "Burr distribution");
     endfunction
 
     function this = set.alpha (this, alpha)
@@ -217,13 +353,13 @@ classdef BurrDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {BurrDistribution} {@var{p} =} icdf (@var{pd}, @var{p})
+    ## @deftypefn  {BurrDistribution} {@var{x} =} icdf (@var{pd}, @var{p})
     ##
     ## Compute the inverse cumulative distribution function (iCDF).
     ##
-    ## @code{@var{p} = icdf (@var{pd}, @var{x})} computes the quantile (the
+    ## @code{@var{x} = icdf (@var{pd}, @var{p})} computes the quantile (the
     ## inverse of the CDF) of the probability distribution object, @var{pd},
-    ## evaluated at the values in @var{x}.
+    ## evaluated at the values in @var{p}.
     ##
     ## @end deftypefn
     function x = icdf (this, p)
@@ -310,8 +446,8 @@ classdef BurrDistribution
     ##
     ## Compute the negative loglikelihood of a probability distribution.
     ##
-    ## @code{@var{m} = negloglik (@var{pd})} computes the negative loglikelihood
-    ## of the probability distribution object, @var{pd}.
+    ## @code{@var{nlogL} = negloglik (@var{pd})} computes the negative
+    ## loglikelihood of the probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
     function nlogL = negloglik (this)
@@ -337,7 +473,7 @@ classdef BurrDistribution
     ## probability distribution object, @var{pd}.
     ##
     ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes the
-    ## confidence intervals with additional options specified specified by
+    ## confidence intervals with additional options specified by
     ## @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
@@ -400,7 +536,7 @@ classdef BurrDistribution
     ##
     ## Plot a probability distribution object.
     ##
-    ## @code{plot (@var{pd}} plots a probability density function (PDF) of the
+    ## @code{plot (@var{pd})} plots a probability density function (PDF) of the
     ## probability distribution object @var{pd}.  If @var{pd} contains data,
     ## which have been fitted by @code{fitdist}, the PDF is superimposed over a
     ## histogram of the data.
@@ -409,7 +545,7 @@ classdef BurrDistribution
     ## options with the @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
-    ## @headitem @tab @var{Name} @tab @var{Value}
+    ## @headitem @var{Name} @tab @tab @var{Value}
     ##
     ## @item @qcode{"PlotType"} @tab @tab A character vector specifying the plot
     ## type.  @qcode{"pdf"} plots the probability density function (PDF).  When
@@ -473,10 +609,9 @@ classdef BurrDistribution
     ## @var{setparam}, @qcode{"Display"}, @qcode{"on"})} also plots the profile
     ## likelihood against the user-defined range of the selected parameter.
     ##
-    ## For the generalized extreme value distribution, @qcode{@var{pnum} = 1}
-    ## selects the parameter @qcode{alpha}, @qcode{@var{pnum} = 2} selects the
-    ## parameter @var{c}, and @qcode{@var{pnum} = 3} selects the parameter
-    ## @var{k}.
+    ## For the Burr distribution, @qcode{@var{pnum} = 1} selects the parameter
+    ## @qcode{alpha}, @qcode{@var{pnum} = 2} selects the parameter @qcode{c},
+    ## and @qcode{@var{pnum} = 3} selects the parameter @qcode{k}.
     ##
     ## When opted to display the profile likelihood plot, @code{proflik} also
     ## plots the baseline loglikelihood computed at the lower bound of the 95%
@@ -496,17 +631,17 @@ classdef BurrDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {BurrDistribution} {@var{y} =} random (@var{pd})
-    ## @deftypefnx {BurrDistribution} {@var{y} =} random (@var{pd}, @var{rows})
-    ## @deftypefnx {BurrDistribution} {@var{y} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
-    ## @deftypefnx {BurrDistribution} {@var{y} =} random (@var{pd}, [@var{sz}])
+    ## @deftypefn  {BurrDistribution} {@var{r} =} random (@var{pd})
+    ## @deftypefnx {BurrDistribution} {@var{r} =} random (@var{pd}, @var{rows})
+    ## @deftypefnx {BurrDistribution} {@var{r} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
+    ## @deftypefnx {BurrDistribution} {@var{r} =} random (@var{pd}, [@var{sz}])
     ##
     ## Generate random arrays from the probability distribution object.
     ##
     ## @code{@var{r} = random (@var{pd})} returns a random number from the
     ## distribution object @var{pd}.
     ##
-    ## When called with a single size argument, @code{betarnd} returns a square
+    ## When called with a single size argument, @code{burrrnd} returns a square
     ## matrix with the dimension specified.  When called with more than one
     ## scalar argument, the first two arguments are taken as the number of rows
     ## and columns and any further arguments specify additional matrix
@@ -560,13 +695,14 @@ classdef BurrDistribution
     ##
     ## Truncate a probability distribution.
     ##
-    ## @code{@var{t} = truncate (@var{pd})} returns a probability distribution
-    ## @var{t}, which is the probability distribution @var{pd} truncated to the
-    ## specified interval with lower limit, @var{lower}, and upper limit,
-    ## @var{upper}.  If @var{pd} is fitted to data with @code{fitdist}, the
-    ## returned probability distribution @var{t} is not fitted, does not contain
-    ## any data or estimated values, and it is as it has been created with the
-    ## @var{makedist} function, but it includes the truncation interval.
+    ## @code{@var{t} = truncate (@var{pd}, @var{lower}, @var{upper})} returns a
+    ## probability distribution @var{t}, which is the probability distribution
+    ## @var{pd} truncated to the specified interval with lower limit, @var{lower},
+    ## and upper limit, @var{upper}.  If @var{pd} is fitted to data with
+    ## @code{fitdist}, the returned probability distribution @var{t} is not
+    ## fitted, does not contain any data or estimated values, and it is as it
+    ## has been created with the @var{makedist} function, but it includes the
+    ## truncation interval.
     ##
     ## @end deftypefn
     function this = truncate (this, lower, upper)
@@ -590,7 +726,7 @@ classdef BurrDistribution
     ##
     ## Compute the variance of a probability distribution.
     ##
-    ## @code{@var{v} = var (@var{pd})} computes the standard deviation of the
+    ## @code{@var{v} = var (@var{pd})} computes the variance of the
     ## probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
@@ -689,38 +825,6 @@ endfunction
 %!                [" alpha = %0.2f, c =  %0.2f, and k = %0.2f"]);
 %! title (sprintf (msg, pd.alpha, pd.c, pd.k))
 
-%!demo
-%! ## Plot the PDF of a Burr type XII distribution, with parameters alpha = 1,
-%! ## c = 2, and k = 1, truncated at [0, 2] intervals. Generate 10000 random
-%! ## samples from this truncated distribution and superimpose a histogram with
-%! ## 100 bins scaled accordingly
-%!
-%! pd = makedist ("Burr", "alpha", 1, "c", 2, "k", 1)
-%! t = truncate (pd, 0.5, 2.5)
-%! rand ("seed", 21);
-%! data = random (t, 10000, 1);
-%! plot (t)
-%! title ("Burr type XII distribution (alpha = 1, c = 2, k = 1) truncated at [0.5, 2.5]")
-%! hold on
-%! hist (data, 100, 50)
-%! hold off
-
-%!demo
-%! ## Generate a data set of 100 random samples from a Burr type XII
-%! ## distribution with parameters alpha = 1, c = 2, and k = 1.  Fit a Burr type
-%! ## XII  distribution to this data and plot its CDF superimposed over an
-%! ## empirical CDF of the data
-%!
-%! pd = makedist ("Burr", "alpha", 1, "c", 2, "k", 1)
-%! rand ("seed", 21);
-%! data = random (pd, 100, 1);
-%! pd = fitdist (data, "Burr")
-%! plot (pd, "plottype", "cdf")
-%! msg = strcat (["Fitted Burr type XII distribution with"], ...
-%!                [" alpha = %0.2f, c =  %0.2f, and k = %0.2f"]);
-%! title (sprintf (msg, pd.alpha, pd.c, pd.k))
-%! legend ({"empirical CDF", "fitted CDF"}, "location", "east")
-
 ## Test output
 %!shared pd, t
 %! pd = BurrDistribution;
