@@ -1,4 +1,5 @@
 ## Copyright (C) 2024 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2025 Swayam Shah <swayamshah66@gmail.com>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -17,89 +18,201 @@
 
 classdef PoissonDistribution
   ## -*- texinfo -*-
-  ## @deftypefn {statistics} PoissonDistribution
+  ## @deftp {statistics} PoissonDistribution
   ##
   ## Poisson probability distribution object.
   ##
   ## A @code{PoissonDistribution} object consists of parameters, a model
   ## description, and sample data for a Poisson probability distribution.
   ##
-  ## The Poisson distribution uses the following parameters.
-  ##
-  ## @multitable @columnfractions 0.25 0.48 0.27
-  ## @headitem @var{Parameter} @tab @var{Description} @tab @var{Support}
-  ##
-  ## @item @qcode{lambda} @tab Rate parameter @tab @math{lambda > 0}
-  ## @end multitable
+  ## The Poisson distribution is a discrete probability distribution that
+  ## models the number of events occurring in a fixed interval of time or space,
+  ## given a constant average rate of occurrence. It is defined by the rate
+  ## parameter @var{lambda}.
   ##
   ## There are several ways to create a @code{PoissonDistribution} object.
   ##
   ## @itemize
   ## @item Fit a distribution to data using the @code{fitdist} function.
-  ## @item Create a distribution with specified parameter values using the
+  ## @item Create a distribution with fixed parameter values using the
   ## @code{makedist} function.
   ## @item Use the constructor @qcode{PoissonDistribution (@var{lambda})}
-  ## to create a Poisson distribution with specified parameter values.
+  ## to create a Poisson distribution with fixed parameter value @var{lambda}.
   ## @item Use the static method @qcode{PoissonDistribution.fit (@var{x},
-  ## @var{censor}, @var{freq}, @var{options})} to a distribution to data @var{x}.
+  ## @var{freq})} to fit a distribution to the data in @var{x} using
+  ## the same input arguments as the @code{poissfit} function.
   ## @end itemize
   ##
   ## It is highly recommended to use @code{fitdist} and @code{makedist}
-  ## functions to create probability distribution objects, instead of the
-  ## constructor and the aforementioned static method.
-  ##
-  ## A @code{PoissonDistribution} object contains the following properties,
-  ## which can be accessed using dot notation.
-  ##
-  ## @multitable @columnfractions 0.25 0.25 0.25 0.25
-  ## @item @qcode{DistributionName} @tab @qcode{DistributionCode} @tab
-  ## @qcode{NumParameters} @tab @qcode{ParameterNames}
-  ## @item @qcode{ParameterDescription} @tab @qcode{ParameterValues} @tab
-  ## @qcode{ParameterValues} @tab @qcode{ParameterCI}
-  ## @item @qcode{ParameterIsFixed} @tab @qcode{Truncation} @tab
-  ## @qcode{IsTruncated} @tab @qcode{InputData}
-  ## @end multitable
-  ##
-  ## A @code{PoissonDistribution} object contains the following methods:
-  ## @code{cdf}, @code{icdf}, @code{iqr}, @code{mean}, @code{median},
-  ## @code{negloglik}, @code{paramci}, @code{pdf}, @code{plot}, @code{proflik},
-  ## @code{random}, @code{std}, @code{truncate}, @code{var}.
+  ## functions to create probability distribution objects, instead of the class
+  ## constructor or the aforementioned static method.
   ##
   ## Further information about the Poisson distribution can be found at
   ## @url{https://en.wikipedia.org/wiki/Poisson_distribution}
   ##
   ## @seealso{fitdist, makedist, poisscdf, poissinv, poisspdf, poissrnd,
   ## poissfit, poisslike, poisstat}
-  ## @end deftypefn
+  ## @end deftp
 
   properties (Dependent = true)
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} lambda
+    ##
+    ## Rate parameter
+    ##
+    ## A positive scalar value characterizing the rate of the
+    ## Poisson distribution. You can access the @qcode{lambda}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     lambda
   endproperties
 
   properties (GetAccess = public, Constant = true)
-    CensoringAllowed = false;
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} DistributionName
+    ##
+    ## Probability distribution name
+    ##
+    ## A character vector specifying the name of the probability distribution
+    ## object. This property is read-only.
+    ##
+    ## @end deftp
     DistributionName = "PoissonDistribution";
-    DistributionCode = "poiss";
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} NumParameters
+    ##
+    ## Number of parameters
+    ##
+    ## A scalar integer value specifying the number of parameters characterizing
+    ## the probability distribution. This property is read-only.
+    ##
+    ## @end deftp
     NumParameters = 1;
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} ParameterNames
+    ##
+    ## Names of parameters
+    ##
+    ## A @math{1x1} cell array of character vectors with each element containing
+    ## the name of a distribution parameter. This property is read-only.
+    ##
+    ## @end deftp
     ParameterNames = {"lambda"};
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} ParameterDescription
+    ##
+    ## Description of parameters
+    ##
+    ## A @math{1x1} cell array of character vectors with each element containing
+    ## a short description of a distribution parameter. This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterDescription = {"Rate"};
   endproperties
 
-  properties (GetAccess = public, Constant = true)
+  properties (GetAccess = public, Constant = true, Hidden)
+    CensoringAllowed = false;
+    DistributionCode = "poiss";
     ParameterRange = [realmin; Inf];
     ParameterLogCI = true;
   endproperties
 
-  properties (GetAccess = public , SetAccess = protected)
+  properties (GetAccess = public, SetAccess = protected)
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} ParameterValues
+    ##
+    ## Distribution parameter values
+    ##
+    ## A @math{1x1} numeric vector containing the values of the distribution
+    ## parameters. This property is read-only. You can change the distribution
+    ## parameters by assigning new values to the @qcode{lambda} property.
+    ##
+    ## @end deftp
     ParameterValues
-    ParameterCI
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} ParameterCovariance
+    ##
+    ## Covariance matrix of the parameter estimates
+    ##
+    ## A @math{1x1} numeric matrix containing the variance of the parameter
+    ## estimate. This matrix is only meaningful when the distribution was fitted
+    ## to data. If the distribution object was created with fixed parameters,
+    ## or a parameter of a fitted distribution is modified, then the
+    ## variance is zero. This property is read-only.
+    ##
+    ## @end deftp
     ParameterCovariance
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} ParameterIsFixed
+    ##
+    ## Flag for fixed parameters
+    ##
+    ## A logical scalar specifying whether the parameter is fixed or estimated.
+    ## A @qcode{true} value corresponds to a fixed parameter, a @qcode{false}
+    ## value corresponds to a parameter estimate. This property is read-only.
+    ##
+    ## @end deftp
     ParameterIsFixed
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} Truncation
+    ##
+    ## Truncation interval
+    ##
+    ## A @math{1x2} numeric vector specifying the truncation interval for the
+    ## probability distribution. The first element contains the lower boundary,
+    ## the second element contains the upper boundary. This property is read-only.
+    ## You can only truncate a probability distribution with the
+    ## @qcode{truncate} method.
+    ##
+    ## @end deftp
     Truncation
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} IsTruncated
+    ##
+    ## Flag for truncated probability distribution
+    ##
+    ## A logical scalar value specifying whether a probability distribution is
+    ## truncated or not. This property is read-only.
+    ##
+    ## @end deftp
     IsTruncated
+
+    ## -*- texinfo -*-
+    ## @deftp {PoissonDistribution} {property} InputData
+    ##
+    ## Data used for fitting a probability distribution
+    ##
+    ## A scalar structure containing the following fields:
+    ## @itemize
+    ## @item @qcode{data}: a numeric vector containing the data used for
+    ## distribution fitting.
+    ## @item @qcode{cens}: a numeric vector of logical values indicating
+    ## censoring information corresponding to the elements of the data used for
+    ## distribution fitting. If no censoring vector was used for distribution
+    ## fitting, then this field defaults to an empty array.
+    ## @item @qcode{freq}: a numeric vector of non-negative integer values
+    ## containing the frequency information corresponding to the elements of the
+    ## data used for distribution fitting. If no frequency vector was used for
+    ## distribution fitting, then this field defaults to an empty array.
+    ## @end itemize
+    ##
+    ## @end deftp
     InputData
   endproperties
 
+  properties (GetAccess = public, SetAccess = protected, Hidden)
+    ParameterCI
+  endproperties
+
   methods (Hidden)
 
     function this = PoissonDistribution (lambda)
@@ -185,13 +298,13 @@ classdef PoissonDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {PoissonDistribution} {@var{p} =} icdf (@var{pd}, @var{p})
+    ## @deftypefn  {PoissonDistribution} {@var{x} =} icdf (@var{pd}, @var{p})
     ##
     ## Compute the inverse cumulative distribution function (iCDF).
     ##
-    ## @code{@var{p} = icdf (@var{pd}, @var{x})} computes the quantile (the
+    ## @code{@var{x} = icdf (@var{pd}, @var{p})} computes the quantile (the
     ## inverse of the CDF) of the probability distribution object, @var{pd},
-    ## evaluated at the values in @var{x}.
+    ## evaluated at the values in @var{p}.
     ##
     ## @end deftypefn
     function x = icdf (this, p)
@@ -294,8 +407,8 @@ classdef PoissonDistribution
     ##
     ## Compute the negative loglikelihood of a probability distribution.
     ##
-    ## @code{@var{m} = negloglik (@var{pd})} computes the negative loglikelihood
-    ## of the probability distribution object, @var{pd}.
+    ## @code{@var{nlogL} = negloglik (@var{pd})} computes the negative
+    ## loglikelihood of the probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
     function nlogL = negloglik (this)
@@ -319,8 +432,8 @@ classdef PoissonDistribution
     ## boundaries of the 95% confidence interval for each parameter of the
     ## probability distribution object, @var{pd}.
     ##
-    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes the
-    ## confidence intervals with additional options specified specified by
+    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes
+    ## the confidence intervals with additional options specified by
     ## @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
@@ -383,7 +496,7 @@ classdef PoissonDistribution
     ##
     ## Plot a probability distribution object.
     ##
-    ## @code{plot (@var{pd}} plots a probability density function (PDF) of the
+    ## @code{plot (@var{pd})} plots a probability density function (PDF) of the
     ## probability distribution object @var{pd}.  If @var{pd} contains data,
     ## which have been fitted by @code{fitdist}, the PDF is superimposed over a
     ## histogram of the data.
@@ -392,7 +505,7 @@ classdef PoissonDistribution
     ## options with the @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
-    ## @headitem @tab @var{Name} @tab @var{Value}
+    ## @headitem @var{Name} @tab @tab @var{Value}
     ##
     ## @item @qcode{"PlotType"} @tab @tab A character vector specifying the plot
     ## type.  @qcode{"pdf"} plots the probability density function (PDF).  When
@@ -407,10 +520,9 @@ classdef PoissonDistribution
     ## plot the PDF or CDF of a discrete distribution object as a line plot or a
     ## stem plot, by specifying @qcode{false} or @qcode{true}, respectively.  By
     ## default, it is @qcode{true} for discrete distributions and @qcode{false}
-    ## for continuous distributions.  When @var{pd} is a continuous distribution
-    ## object, option is ignored.
+    ## for continuous distributions.
     ##
-    ## @item @qcode{"Parent"} @tab @tab An axes graphics object for plot.  If
+    ## @item @qcode{"Parent"} @tab @tab An axes graphics object for the plot.  If
     ## not specified, the @code{plot} function plots into the current axes or
     ## creates a new axes object if one does not exist.
     ## @end multitable
@@ -457,12 +569,12 @@ classdef PoissonDistribution
     ## likelihood against the user-defined range of the selected parameter.
     ##
     ## For the Poisson distribution, @qcode{@var{pnum} = 1} selects the
-    ## parameter @var{lambda}.
+    ## parameter @qcode{lambda}.
     ##
     ## When opted to display the profile likelihood plot, @code{proflik} also
     ## plots the baseline loglikelihood computed at the lower bound of the 95%
     ## confidence interval and estimated maximum likelihood.  The latter might
-    ## not be observable if it is outside of the used-defined range of parameter
+    ## not be observable if it is outside of the user-defined range of parameter
     ## values.
     ##
     ## @end deftypefn
@@ -477,17 +589,17 @@ classdef PoissonDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {PoissonDistribution} {@var{y} =} random (@var{pd})
-    ## @deftypefnx {PoissonDistribution} {@var{y} =} random (@var{pd}, @var{rows})
-    ## @deftypefnx {PoissonDistribution} {@var{y} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
-    ## @deftypefnx {PoissonDistribution} {@var{y} =} random (@var{pd}, [@var{sz}])
+    ## @deftypefn  {PoissonDistribution} {@var{r} =} random (@var{pd})
+    ## @deftypefnx {PoissonDistribution} {@var{r} =} random (@var{pd}, @var{rows})
+    ## @deftypefnx {PoissonDistribution} {@var{r} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
+    ## @deftypefnx {PoissonDistribution} {@var{r} =} random (@var{pd}, [@var{sz}])
     ##
     ## Generate random arrays from the probability distribution object.
     ##
     ## @code{@var{r} = random (@var{pd})} returns a random number from the
     ## distribution object @var{pd}.
     ##
-    ## When called with a single size argument, @code{betarnd} returns a square
+    ## When called with a single size argument, @code{poissrnd} returns a square
     ## matrix with the dimension specified.  When called with more than one
     ## scalar argument, the first two arguments are taken as the number of rows
     ## and columns and any further arguments specify additional matrix
@@ -541,13 +653,14 @@ classdef PoissonDistribution
     ##
     ## Truncate a probability distribution.
     ##
-    ## @code{@var{t} = truncate (@var{pd})} returns a probability distribution
-    ## @var{t}, which is the probability distribution @var{pd} truncated to the
-    ## specified interval with lower limit, @var{lower}, and upper limit,
-    ## @var{upper}.  If @var{pd} is fitted to data with @code{fitdist}, the
-    ## returned probability distribution @var{t} is not fitted, does not contain
-    ## any data or estimated values, and it is as it has been created with the
-    ## @var{makedist} function, but it includes the truncation interval.
+    ## @code{@var{t} = truncate (@var{pd}, @var{lower}, @var{upper})} returns a
+    ## probability distribution @var{t}, which is the probability distribution
+    ## @var{pd} truncated to the specified interval with lower limit,
+    ## @var{lower}, and upper limit, @var{upper}.  If @var{pd} is fitted to data
+    ## with @code{fitdist}, the returned probability distribution @var{t} is not
+    ## fitted, does not contain any data or estimated values, and it is as it
+    ## has been created with the @var{makedist} function, but it includes the
+    ## truncation interval.
     ##
     ## @end deftypefn
     function this = truncate (this, lower, upper)
@@ -576,7 +689,7 @@ classdef PoissonDistribution
     ##
     ## Compute the variance of a probability distribution.
     ##
-    ## @code{@var{v} = var (@var{pd})} computes the standard deviation of the
+    ## @code{@var{v} = var (@var{pd})} computes the variance of the
     ## probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
@@ -652,6 +765,19 @@ function checkparams (lambda)
   endif
 endfunction
 
+%!demo
+%! ## Generate a data set of 5000 random samples from a Poisson distribution with
+%! ## parameter lambda = 5.  Fit a Poisson distribution to this data and plot
+%! ## a PDF of the fitted distribution superimposed on a histogram of the data.
+%!
+%! pd_fixed = makedist ("Poisson", "lambda", 5)
+%! rand ("seed", 2);
+%! data = random (pd_fixed, 5000, 1);
+%! pd_fitted = fitdist (data, "Poisson")
+%! plot (pd_fitted)
+%! msg = "Fitted Poisson distribution with lambda = %0.2f";
+%! title (sprintf (msg, pd_fitted.lambda))
+
 ## Test output
 %!shared pd, t, t_inf
 %! pd = PoissonDistribution;
