@@ -1,4 +1,5 @@
 ## Copyright (C) 2024 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2025 Swayam Shah <swayamshah66@gmail.com>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -17,91 +18,218 @@
 
 classdef RicianDistribution
   ## -*- texinfo -*-
-  ## @deftypefn {statistics} RicianDistribution
+  ## @deftp {statistics} RicianDistribution
   ##
   ## Rician probability distribution object.
   ##
   ## A @code{RicianDistribution} object consists of parameters, a model
   ## description, and sample data for a Rician probability distribution.
   ##
-  ## The Rician distribution uses the following parameters.
-  ##
-  ## @multitable @columnfractions 0.25 0.48 0.27
-  ## @headitem @var{Parameter} @tab @var{Description} @tab @var{Support}
-  ##
-  ## @item @qcode{s} @tab Noncentrality parameter @tab @math{s >= 0}
-  ## @item @qcode{sigma} @tab Scale parameter @tab @math{sigma > 0}
-  ## @end multitable
+  ## The Rician distribution is a continuous probability distribution that
+  ## models the magnitude of a signal in the presence of Gaussian noise.  It is
+  ## defined by noncentrality parameter @var{s} and scale parameter @var{sigma}.
   ##
   ## There are several ways to create a @code{RicianDistribution} object.
   ##
   ## @itemize
   ## @item Fit a distribution to data using the @code{fitdist} function.
-  ## @item Create a distribution with specified parameter values using the
+  ## @item Create a distribution with fixed parameter values using the
   ## @code{makedist} function.
   ## @item Use the constructor @qcode{RicianDistribution (@var{s}, @var{sigma})}
-  ## to create a Rician distribution with specified parameter values.
+  ## to create a Rician distribution with fixed parameter values @var{s} and
+  ## @var{sigma}.
   ## @item Use the static method @qcode{RicianDistribution.fit (@var{x},
-  ## @var{censor}, @var{freq}, @var{options})} to a distribution to data @var{x}.
+  ## @var{censor}, @var{freq}, @var{options})} to fit a distribution to data
+  ## @var{x}.
   ## @end itemize
   ##
   ## It is highly recommended to use @code{fitdist} and @code{makedist}
-  ## functions to create probability distribution objects, instead of the
-  ## constructor and the aforementioned static method.
-  ##
-  ## A @code{RicianDistribution} object contains the following properties,
-  ## which can be accessed using dot notation.
-  ##
-  ## @multitable @columnfractions 0.25 0.25 0.25 0.25
-  ## @item @qcode{DistributionName} @tab @qcode{DistributionCode} @tab
-  ## @qcode{NumParameters} @tab @qcode{ParameterNames}
-  ## @item @qcode{ParameterDescription} @tab @qcode{ParameterValues} @tab
-  ## @qcode{ParameterValues} @tab @qcode{ParameterCI}
-  ## @item @qcode{ParameterIsFixed} @tab @qcode{Truncation} @tab
-  ## @qcode{IsTruncated} @tab @qcode{InputData}
-  ## @end multitable
-  ##
-  ## A @code{RicianDistribution} object contains the following methods:
-  ## @code{cdf}, @code{icdf}, @code{iqr}, @code{mean}, @code{median},
-  ## @code{negloglik}, @code{paramci}, @code{pdf}, @code{plot}, @code{proflik},
-  ## @code{random}, @code{std}, @code{truncate}, @code{var}.
+  ## functions to create probability distribution objects, instead of the class
+  ## constructor or the aforementioned static method.
   ##
   ## Further information about the Rician distribution can be found at
   ## @url{https://en.wikipedia.org/wiki/Rice_distribution}
   ##
   ## @seealso{fitdist, makedist, ricecdf, riceinv, ricepdf, ricernd, ricefit,
   ## ricelike, ricestat}
-  ## @end deftypefn
+  ## @end deftp
 
   properties (Dependent = true)
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} s
+    ##
+    ## Noncentrality parameter
+    ##
+    ## A non-negative scalar value characterizing the noncentrality of the
+    ## Rician distribution.  You can access the @qcode{s} property using dot
+    ## name assignment.
+    ##
+    ## @end deftp
     s
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} sigma
+    ##
+    ## Scale parameter
+    ##
+    ## A positive scalar value characterizing the scale of the Rician
+    ## distribution.  You can access the @qcode{sigma} property using dot name
+    ## assignment.
+    ##
+    ## @end deftp
     sigma
   endproperties
 
   properties (GetAccess = public, Constant = true)
-    CensoringAllowed = true;
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} DistributionName
+    ##
+    ## Probability distribution name
+    ##
+    ## A character vector specifying the name of the probability distribution
+    ## object.  This property is read-only.
+    ##
+    ## @end deftp
     DistributionName = "RicianDistribution";
-    DistributionCode = "rice";
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} NumParameters
+    ##
+    ## Number of parameters
+    ##
+    ## A scalar integer value specifying the number of parameters characterizing
+    ## the probability distribution.  This property is read-only.
+    ##
+    ## @end deftp
     NumParameters = 2;
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} ParameterNames
+    ##
+    ## Names of parameters
+    ##
+    ## A @math{2x1} cell array of character vectors with each element containing
+    ## the name of a distribution parameter.  This property is read-only.
+    ##
+    ## @end deftp
     ParameterNames = {"s", "sigma"};
-    ParameterDescription = {"Non-centrality Distance", "Scale"};
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} ParameterDescription
+    ##
+    ## Description of parameters
+    ##
+    ## A @math{2x1} cell array of character vectors with each element containing
+    ## a short description of a distribution parameter.  This property is
+    ## read-only.
+    ##
+    ## @end deftp
+    ParameterDescription = {"Noncentrality", "Scale"};
   endproperties
 
-  properties (GetAccess = public, Constant = true)
+  properties (GetAccess = public, Constant = true, Hidden)
+    CensoringAllowed = true;
+    DistributionCode = "rice";
     ParameterRange = [0, realmin; Inf, Inf];
     ParameterLogCI = [true, true];
   endproperties
 
-  properties (GetAccess = public , SetAccess = protected)
+  properties (GetAccess = public, SetAccess = protected)
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} ParameterValues
+    ##
+    ## Distribution parameter values
+    ##
+    ## A @math{2x1} numeric vector containing the values of the distribution
+    ## parameters.  This property is read-only.  You can change the distribution
+    ## parameters by assigning new values to the @qcode{s} and @qcode{sigma}
+    ## properties.
+    ##
+    ## @end deftp
     ParameterValues
-    ParameterCI
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} ParameterCovariance
+    ##
+    ## Covariance matrix of the parameter estimates
+    ##
+    ## A @math{2x2} numeric matrix containing the variance-covariance of the
+    ## parameter estimates.  Diagonal elements contain the variance of each
+    ## estimated parameter, and non-diagonal elements contain the covariance
+    ## between the parameter estimates. The covariance matrix is only
+    ## meaningful when the distribution was fitted to data.  If the distribution
+    ## object was created with fixed parameters, or a parameter of a fitted
+    ## distribution is modified, then all elements of the variance-covariance
+    ## are zero.  This property is read-only.
+    ##
+    ## @end deftp
     ParameterCovariance
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} ParameterIsFixed
+    ##
+    ## Flag for fixed parameters
+    ##
+    ## A @math{1x2} logical vector specifying which parameters are fixed and
+    ## which are estimated.  @qcode{true} values correspond to fixed parameters,
+    ## @qcode{false} values correspond to parameter estimates.  This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterIsFixed
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} Truncation
+    ##
+    ## Truncation interval
+    ##
+    ## A @math{1x2} numeric vector specifying the truncation interval for the
+    ## probability distribution.  First element contains the lower boundary,
+    ## second element contains the upper boundary.  This property is read-only.
+    ## You can only truncate a probability distribution with the
+    ## @qcode{truncate} method.
+    ##
+    ## @end deftp
     Truncation
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} IsTruncated
+    ##
+    ## Flag for truncated probability distribution
+    ##
+    ## A logical scalar value specifying whether a probability distribution is
+    ## truncated or not.  This property is read-only.
+    ##
+    ## @end deftp
     IsTruncated
+
+    ## -*- texinfo -*-
+    ## @deftp {RicianDistribution} {property} InputData
+    ##
+    ## Data used for fitting a probability distribution
+    ##
+    ## A scalar structure containing the following fields:
+    ## @itemize
+    ## @item @qcode{data}: a numeric vector containing the data used for
+    ## distribution fitting.
+    ## @item @qcode{cens}: a numeric vector of logical values indicating
+    ## censoring information corresponding to the elements of the data used for
+    ## distribution fitting.  If no censoring vector was used for distribution
+    ## fitting, then this field defaults to an empty array.
+    ## @item @qcode{freq}: a numeric vector of non-negative integer values
+    ## containing the frequency information corresponding to the elements of the
+    ## data used for distribution fitting.  If no frequency vector was used for
+    ## distribution fitting, then this field defaults to an empty array.
+    ## @end itemize
+    ##
+    ## @end deftp
     InputData
   endproperties
 
+  properties (GetAccess = public, SetAccess = protected, Hidden)
+    ParameterCI
+  endproperties
+
   methods (Hidden)
 
     function this = RicianDistribution (s, sigma)
@@ -200,13 +328,13 @@ classdef RicianDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {RicianDistribution} {@var{p} =} icdf (@var{pd}, @var{p})
+    ## @deftypefn  {RicianDistribution} {@var{x} =} icdf (@var{pd}, @var{p})
     ##
     ## Compute the inverse cumulative distribution function (iCDF).
     ##
-    ## @code{@var{p} = icdf (@var{pd}, @var{x})} computes the quantile (the
+    ## @code{@var{x} = icdf (@var{pd}, @var{p})} computes the quantile (the
     ## inverse of the CDF) of the probability distribution object, @var{pd},
-    ## evaluated at the values in @var{x}.
+    ## evaluated at the values in @var{p}.
     ##
     ## @end deftypefn
     function x = icdf (this, p)
@@ -293,8 +421,8 @@ classdef RicianDistribution
     ##
     ## Compute the negative loglikelihood of a probability distribution.
     ##
-    ## @code{@var{m} = negloglik (@var{pd})} computes the negative loglikelihood
-    ## of the probability distribution object, @var{pd}.
+    ## @code{@var{nlogL} = negloglik (@var{pd})} computes the negative
+    ## loglikelihood of the probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
     function nlogL = negloglik (this)
@@ -319,8 +447,8 @@ classdef RicianDistribution
     ## boundaries of the 95% confidence interval for each parameter of the
     ## probability distribution object, @var{pd}.
     ##
-    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes the
-    ## confidence intervals with additional options specified specified by
+    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes
+    ## the confidence intervals with additional options specified by
     ## @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
@@ -383,7 +511,7 @@ classdef RicianDistribution
     ##
     ## Plot a probability distribution object.
     ##
-    ## @code{plot (@var{pd}} plots a probability density function (PDF) of the
+    ## @code{plot (@var{pd})} plots a probability density function (PDF) of the
     ## probability distribution object @var{pd}.  If @var{pd} contains data,
     ## which have been fitted by @code{fitdist}, the PDF is superimposed over a
     ## histogram of the data.
@@ -392,7 +520,7 @@ classdef RicianDistribution
     ## options with the @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
-    ## @headitem @tab @var{Name} @tab @var{Value}
+    ## @headitem @var{Name} @tab @tab @var{Value}
     ##
     ## @item @qcode{"PlotType"} @tab @tab A character vector specifying the plot
     ## type.  @qcode{"pdf"} plots the probability density function (PDF).  When
@@ -458,7 +586,7 @@ classdef RicianDistribution
     ##
     ## For the Rician distribution, @qcode{@var{pnum} = 1} selects the
     ## parameter @qcode{s} and @qcode{@var{pnum} = 2} selects the parameter
-    ## @var{sigma}.
+    ## @qcode{sigma}.
     ##
     ## When opted to display the profile likelihood plot, @code{proflik} also
     ## plots the baseline loglikelihood computed at the lower bound of the 95%
@@ -478,17 +606,17 @@ classdef RicianDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {RicianDistribution} {@var{y} =} random (@var{pd})
-    ## @deftypefnx {RicianDistribution} {@var{y} =} random (@var{pd}, @var{rows})
-    ## @deftypefnx {RicianDistribution} {@var{y} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
-    ## @deftypefnx {RicianDistribution} {@var{y} =} random (@var{pd}, [@var{sz}])
+    ## @deftypefn  {RicianDistribution} {@var{r} =} random (@var{pd})
+    ## @deftypefnx {RicianDistribution} {@var{r} =} random (@var{pd}, @var{rows})
+    ## @deftypefnx {RicianDistribution} {@var{r} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
+    ## @deftypefnx {RicianDistribution} {@var{r} =} random (@var{pd}, [@var{sz}])
     ##
     ## Generate random arrays from the probability distribution object.
     ##
     ## @code{@var{r} = random (@var{pd})} returns a random number from the
     ## distribution object @var{pd}.
     ##
-    ## When called with a single size argument, @code{betarnd} returns a square
+    ## When called with a single size argument, @code{ricernd} returns a square
     ## matrix with the dimension specified.  When called with more than one
     ## scalar argument, the first two arguments are taken as the number of rows
     ## and columns and any further arguments specify additional matrix
@@ -542,13 +670,14 @@ classdef RicianDistribution
     ##
     ## Truncate a probability distribution.
     ##
-    ## @code{@var{t} = truncate (@var{pd})} returns a probability distribution
-    ## @var{t}, which is the probability distribution @var{pd} truncated to the
-    ## specified interval with lower limit, @var{lower}, and upper limit,
-    ## @var{upper}.  If @var{pd} is fitted to data with @code{fitdist}, the
-    ## returned probability distribution @var{t} is not fitted, does not contain
-    ## any data or estimated values, and it is as it has been created with the
-    ## @var{makedist} function, but it includes the truncation interval.
+    ## @code{@var{t} = truncate (@var{pd}, @var{lower}, @var{upper})} returns a
+    ## probability distribution @var{t}, which is the probability distribution
+    ## @var{pd} truncated to the specified interval with lower limit,
+    ## @var{lower}, and upper limit, @var{upper}.  If @var{pd} is fitted to data
+    ## with @code{fitdist}, the returned probability distribution @var{t} is not
+    ## fitted, does not contain any data or estimated values, and it is as it
+    ## has been created with the @var{makedist} function, but it includes the
+    ## truncation interval.
     ##
     ## @end deftypefn
     function this = truncate (this, lower, upper)
@@ -572,7 +701,7 @@ classdef RicianDistribution
     ##
     ## Compute the variance of a probability distribution.
     ##
-    ## @code{@var{v} = var (@var{pd})} computes the standard deviation of the
+    ## @code{@var{v} = var (@var{pd})} computes the variance of the
     ## probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
@@ -644,7 +773,7 @@ endclassdef
 function checkparams (s, sigma)
   if (! (isscalar (s) && isnumeric (s) && isreal (s) && isfinite (s)
                        && s >= 0 ))
-    error ("RicianDistribution: NU must be a non-negative real scalar.")
+    error ("RicianDistribution: S must be a non-negative real scalar.")
   endif
   if (! (isscalar (sigma) && isnumeric (sigma) && isreal (sigma)
                           && isfinite (sigma) && sigma > 0))
@@ -652,6 +781,19 @@ function checkparams (s, sigma)
   endif
 endfunction
 
+%!demo
+%! ## Generate a data set of 5000 random samples from a Rician distribution with
+%! ## parameters s = 2 and sigma = 1. Fit a Rician distribution to this data and
+%! ## plot a PDF of the fitted distribution superimposed on a histogram of the data.
+%!
+%! pd_fixed = makedist ("Rician", "s", 2, "sigma", 1)
+%! rand ("seed", 2);
+%! data = random (pd_fixed, 5000, 1);
+%! pd_fitted = fitdist (data, "Rician")
+%! plot (pd_fitted)
+%! msg = "Fitted Rician distribution with s = %0.2f and sigma = %0.2f";
+%! title (sprintf (msg, pd_fitted.s, pd_fitted.sigma))
+
 ## Test output
 %!shared pd, t
 %! pd = RicianDistribution;
@@ -684,19 +826,19 @@ endfunction
 
 ## Test input validation
 ## 'RicianDistribution' constructor
-%!error <RicianDistribution: NU must be a non-negative real scalar.> ...
+%!error <RicianDistribution: S must be a non-negative real scalar.> ...
 %! RicianDistribution(-eps, 1)
-%!error <RicianDistribution: NU must be a non-negative real scalar.> ...
+%!error <RicianDistribution: S must be a non-negative real scalar.> ...
 %! RicianDistribution(-1, 1)
-%!error <RicianDistribution: NU must be a non-negative real scalar.> ...
+%!error <RicianDistribution: S must be a non-negative real scalar.> ...
 %! RicianDistribution(Inf, 1)
-%!error <RicianDistribution: NU must be a non-negative real scalar.> ...
+%!error <RicianDistribution: S must be a non-negative real scalar.> ...
 %! RicianDistribution(i, 1)
-%!error <RicianDistribution: NU must be a non-negative real scalar.> ...
+%!error <RicianDistribution: S must be a non-negative real scalar.> ...
 %! RicianDistribution("a", 1)
-%!error <RicianDistribution: NU must be a non-negative real scalar.> ...
+%!error <RicianDistribution: S must be a non-negative real scalar.> ...
 %! RicianDistribution([1, 2], 1)
-%!error <RicianDistribution: NU must be a non-negative real scalar.> ...
+%!error <RicianDistribution: S must be a non-negative real scalar.> ...
 %! RicianDistribution(NaN, 1)
 %!error <RicianDistribution: SIGMA must be a positive real scalar.> ...
 %! RicianDistribution(1, 0)
