@@ -1,4 +1,5 @@
 ## Copyright (C) 2024 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2025 Swayam Shah <swayamshah66@gmail.com>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -17,93 +18,233 @@
 
 classdef tLocationScaleDistribution
   ## -*- texinfo -*-
-  ## @deftypefn {statistics} tLocationScaleDistribution
+  ## @deftp {statistics} tLocationScaleDistribution
   ##
-  ## Weibull probability distribution object.
+  ## Location-Scale Student's T probability distribution object.
   ##
   ## A @code{tLocationScaleDistribution} object consists of parameters, a model
-  ## description, and sample data for a Weibull probability distribution.
+  ## description, and sample data for a location-scale Student's T probability
+  ## distribution.
   ##
-  ## The Weibull distribution uses the following parameters.
-  ##
-  ## @multitable @columnfractions 0.25 0.48 0.27
-  ## @headitem @var{Parameter} @tab @var{Description} @tab @var{Support}
-  ##
-  ## @item @qcode{mu} @tab Location parameter @tab @math{-Inf < mu < Inf}
-  ## @item @qcode{sigma} @tab Scale parameter @tab @math{sigma > 0}
-  ## @item @qcode{nu} @tab Degrees of Freedom @tab @math{nu > 0}
-  ## @end multitable
+  ## The location-scale Student's T distribution is a continuous probability
+  ## distribution that generalizes the standard Student's T distribution by
+  ## including location and scale parameters.  It is defined by location parameter
+  ## @var{mu}, scale parameter @var{sigma}, and degrees of freedom @var{nu}.
   ##
   ## There are several ways to create a @code{tLocationScaleDistribution} object.
   ##
   ## @itemize
   ## @item Fit a distribution to data using the @code{fitdist} function.
-  ## @item Create a distribution with specified parameter values using the
+  ## @item Create a distribution with fixed parameter values using the
   ## @code{makedist} function.
-  ## @item Use the constructor @qcode{tLocationScaleDistribution (@var{lambda},
-  ## @var{mu})} to create a Weibull distribution with specified parameter values.
+  ## @item Use the constructor @qcode{tLocationScaleDistribution (@var{mu},
+  ## @var{sigma}, @var{nu})} to create a location-scale Student's T distribution
+  ## with fixed parameter values @var{mu}, @var{sigma}, and @var{nu}.
   ## @item Use the static method @qcode{tLocationScaleDistribution.fit (@var{x},
-  ## @var{censor}, @var{freq}, @var{options})} to a distribution to data @var{x}.
+  ## @var{censor}, @var{freq}, @var{options})} to fit a distribution to the data
+  ## in @var{x} using the same input arguments as the @code{tlsfit} function.
   ## @end itemize
   ##
   ## It is highly recommended to use @code{fitdist} and @code{makedist}
-  ## functions to create probability distribution objects, instead of the
-  ## constructor and the aforementioned static method.
-  ##
-  ## A @code{tLocationScaleDistribution} object contains the following
-  ## properties, which can be accessed using dot notation.
-  ##
-  ## @multitable @columnfractions 0.25 0.25 0.25 0.25
-  ## @item @qcode{DistributionName} @tab @qcode{DistributionCode} @tab
-  ## @qcode{NumParameters} @tab @qcode{ParameterNames}
-  ## @item @qcode{ParameterDescription} @tab @qcode{ParameterValues} @tab
-  ## @qcode{ParameterValues} @tab @qcode{ParameterCI}
-  ## @item @qcode{ParameterIsFixed} @tab @qcode{Truncation} @tab
-  ## @qcode{IsTruncated} @tab @qcode{InputData}
-  ## @end multitable
-  ##
-  ## A @code{tLocationScaleDistribution} object contains the following methods:
-  ## @code{cdf}, @code{icdf}, @code{iqr}, @code{mean}, @code{median},
-  ## @code{negloglik}, @code{paramci}, @code{pdf}, @code{plot}, @code{proflik},
-  ## @code{random}, @code{std}, @code{truncate}, @code{var}.
+  ## functions to create probability distribution objects, instead of the class
+  ## constructor or the aforementioned static method.
   ##
   ## Further information about the location-scale Student's T distribution can be
-  ## found at @url{https://en.wikipedia.org/wiki/Student%27s_t-distribution#Location-scale_t_distribution}
+  ## found at
+  ## @url{https://en.wikipedia.org/wiki/Student%27s_t-distribution#Location-scale_t_distribution}
   ##
   ## @seealso{fitdist, makedist, tlscdf, tlsinv, tlspdf, tlsrnd, tlsfit,
   ## tlslike, tlsstat}
-  ## @end deftypefn
+  ## @end deftp
 
   properties (Dependent = true)
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} mu
+    ##
+    ## Location parameter
+    ##
+    ## A scalar value characterizing the location of the
+    ## location-scale Student's T distribution.  You can access the @qcode{mu}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     mu
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} sigma
+    ##
+    ## Scale parameter
+    ##
+    ## A positive scalar value characterizing the scale of the
+    ## location-scale Student's T distribution.  You can access the @qcode{sigma}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     sigma
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} nu
+    ##
+    ## Degrees of freedom
+    ##
+    ## A positive scalar value characterizing the degrees of freedom of the
+    ## location-scale Student's T distribution.  You can access the @qcode{nu}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     nu
   endproperties
 
   properties (GetAccess = public, Constant = true)
-    CensoringAllowed = true;
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} DistributionName
+    ##
+    ## Probability distribution name
+    ##
+    ## A character vector specifying the name of the probability distribution
+    ## object.  This property is read-only.
+    ##
+    ## @end deftp
     DistributionName = "tLocationScaleDistribution";
-    DistributionCode = "tls";
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} NumParameters
+    ##
+    ## Number of parameters
+    ##
+    ## A scalar integer value specifying the number of parameters characterizing
+    ## the probability distribution.  This property is read-only.
+    ##
+    ## @end deftp
     NumParameters = 3;
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} ParameterNames
+    ##
+    ## Names of parameters
+    ##
+    ## A @math{3x1} cell array of character vectors with each element containing
+    ## the name of a distribution parameter.  This property is read-only.
+    ##
+    ## @end deftp
     ParameterNames = {"mu", "sigma", "nu"};
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} ParameterDescription
+    ##
+    ## Description of parameters
+    ##
+    ## A @math{3x1} cell array of character vectors with each element containing
+    ## a short description of a distribution parameter.  This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterDescription = {"Location", "Scale", "Degrees of Freedom"};
   endproperties
 
-  properties (GetAccess = public, Constant = true)
+  properties (GetAccess = public, Constant = true, Hidden)
+    CensoringAllowed = true;
+    DistributionCode = "tls";
     ParameterRange = [-Inf, realmin, realmin; Inf, Inf, Inf];
     ParameterLogCI = [false, true, true];
   endproperties
 
   properties (GetAccess = public, SetAccess = protected)
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} ParameterValues
+    ##
+    ## Distribution parameter values
+    ##
+    ## A @math{3x1} numeric vector containing the values of the distribution
+    ## parameters.  This property is read-only. You can change the distribution
+    ## parameters by assigning new values to the @qcode{mu}, @qcode{sigma}, and
+    ## @qcode{nu} properties.
+    ##
+    ## @end deftp
     ParameterValues
-    ParameterCI
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} ParameterCovariance
+    ##
+    ## Covariance matrix of the parameter estimates
+    ##
+    ## A @math{3x3} numeric matrix containing the variance-covariance of the
+    ## parameter estimates.  Diagonal elements contain the variance of each
+    ## estimated parameter, and non-diagonal elements contain the covariance
+    ## between the parameter estimates.  The covariance matrix is only
+    ## meaningful when the distribution was fitted to data.  If the distribution
+    ## object was created with fixed parameters, or a parameter of a fitted
+    ## distribution is modified, then all elements of the variance-covariance
+    ## are zero. This property is read-only.
+    ##
+    ## @end deftp
     ParameterCovariance
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} ParameterIsFixed
+    ##
+    ## Flag for fixed parameters
+    ##
+    ## A @math{1x3} logical vector specifying which parameters are fixed and
+    ## which are estimated.  @qcode{true} values correspond to fixed parameters,
+    ## @qcode{false} values correspond to parameter estimates.  This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterIsFixed
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} Truncation
+    ##
+    ## Truncation interval
+    ##
+    ## A @math{1x2} numeric vector specifying the truncation interval for the
+    ## probability distribution.  First element contains the lower boundary,
+    ## second element contains the upper boundary.  This property is read-only.
+    ## You can only truncate a probability distribution with the
+    ## @qcode{truncate} method.
+    ##
+    ## @end deftp
     Truncation
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} IsTruncated
+    ##
+    ## Flag for truncated probability distribution
+    ##
+    ## A logical scalar value specifying whether a probability distribution is
+    ## truncated or not.  This property is read-only.
+    ##
+    ## @end deftp
     IsTruncated
+
+    ## -*- texinfo -*-
+    ## @deftp {tLocationScaleDistribution} {property} InputData
+    ##
+    ## Data used for fitting a probability distribution
+    ##
+    ## A scalar structure containing the following fields:
+    ## @itemize
+    ## @item @qcode{data}: a numeric vector containing the data used for
+    ## distribution fitting.
+    ## @item @qcode{cens}: a numeric vector of logical values indicating
+    ## censoring information corresponding to the elements of the data used for
+    ## distribution fitting. If no censoring vector was used for distribution
+    ## fitting, then this field defaults to an empty array.
+    ## @item @qcode{freq}: a numeric vector of non-negative integer values
+    ## containing the frequency information corresponding to the elements of the
+    ## data used for distribution fitting.  If no frequency vector was used for
+    ## distribution fitting, then this field defaults to an empty array.
+    ## @end itemize
+    ##
+    ## @end deftp
     InputData
   endproperties
 
+  properties (GetAccess = public, SetAccess = protected, Hidden)
+    ParameterCI
+  endproperties
+
   methods (Hidden)
 
     function this = tLocationScaleDistribution (mu, sigma, nu)
@@ -215,13 +356,13 @@ classdef tLocationScaleDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {tLocationScaleDistribution} {@var{p} =} icdf (@var{pd}, @var{p})
+    ## @deftypefn  {tLocationScaleDistribution} {@var{x} =} icdf (@var{pd}, @var{p})
     ##
     ## Compute the inverse cumulative distribution function (iCDF).
     ##
-    ## @code{@var{p} = icdf (@var{pd}, @var{x})} computes the quantile (the
+    ## @code{@var{x} = icdf (@var{pd}, @var{p})} computes the quantile (the
     ## inverse of the CDF) of the probability distribution object, @var{pd},
-    ## evaluated at the values in @var{x}.
+    ## evaluated at the values in @var{p}.
     ##
     ## @end deftypefn
     function x = icdf (this, p)
@@ -308,8 +449,8 @@ classdef tLocationScaleDistribution
     ##
     ## Compute the negative loglikelihood of a probability distribution.
     ##
-    ## @code{@var{m} = negloglik (@var{pd})} computes the negative loglikelihood
-    ## of the probability distribution object, @var{pd}.
+    ## @code{@var{nlogL} = negloglik (@var{pd})} computes the negative
+    ## loglikelihood of the probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
     function nlogL = negloglik (this)
@@ -334,8 +475,8 @@ classdef tLocationScaleDistribution
     ## boundaries of the 95% confidence interval for each parameter of the
     ## probability distribution object, @var{pd}.
     ##
-    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes the
-    ## confidence intervals with additional options specified specified by
+    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes
+    ## the confidence intervals with additional options specified by
     ## @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
@@ -398,8 +539,8 @@ classdef tLocationScaleDistribution
     ##
     ## Plot a probability distribution object.
     ##
-    ## @code{plot (@var{pd}} plots a probability density function (PDF) of the
-    ## probability distribution object @var{pd}.  If @var{pd} contains data,
+    ## @code{plot (@var{pd})} plots a probability density function (PDF) of the
+    ## probability distribution object @var{pd}. If @var{pd} contains data,
     ## which have been fitted by @code{fitdist}, the PDF is superimposed over a
     ## histogram of the data.
     ##
@@ -407,7 +548,7 @@ classdef tLocationScaleDistribution
     ## options with the @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
-    ## @headitem @tab @var{Name} @tab @var{Value}
+    ## @headitem @var{Name} @tab @tab @var{Value}
     ##
     ## @item @qcode{"PlotType"} @tab @tab A character vector specifying the plot
     ## type.  @qcode{"pdf"} plots the probability density function (PDF).  When
@@ -471,9 +612,10 @@ classdef tLocationScaleDistribution
     ## @var{setparam}, @qcode{"Display"}, @qcode{"on"})} also plots the profile
     ## likelihood against the user-defined range of the selected parameter.
     ##
-    ## For the location-scale T distribution, @qcode{@var{pnum} = 1} selects the
-    ## parameter @qcode{mu}, @qcode{@var{pnum} = 2} selects the parameter
-    ## @qcode{sigma}, and @qcode{@var{pnum} = 3} selects the parameter @var{nu}.
+    ## For the location-scale Student's T distribution, @qcode{@var{pnum} = 1}
+    ## selects the parameter @qcode{mu}, @qcode{@var{pnum} = 2} selects the
+    ## parameter @qcode{sigma}, and @qcode{@var{pnum} = 3} selects the
+    ## parameter @qcode{nu}.
     ##
     ## When opted to display the profile likelihood plot, @code{proflik} also
     ## plots the baseline loglikelihood computed at the lower bound of the 95%
@@ -493,17 +635,17 @@ classdef tLocationScaleDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {tLocationScaleDistribution} {@var{y} =} random (@var{pd})
-    ## @deftypefnx {tLocationScaleDistribution} {@var{y} =} random (@var{pd}, @var{rows})
-    ## @deftypefnx {tLocationScaleDistribution} {@var{y} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
-    ## @deftypefnx {tLocationScaleDistribution} {@var{y} =} random (@var{pd}, [@var{sz}])
+    ## @deftypefn  {tLocationScaleDistribution} {@var{r} =} random (@var{pd})
+    ## @deftypefnx {tLocationScaleDistribution} {@var{r} =} random (@var{pd}, @var{rows})
+    ## @deftypefnx {tLocationScaleDistribution} {@var{r} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
+    ## @deftypefnx {tLocationScaleDistribution} {@var{r} =} random (@var{pd}, [@var{sz}])
     ##
     ## Generate random arrays from the probability distribution object.
     ##
     ## @code{@var{r} = random (@var{pd})} returns a random number from the
     ## distribution object @var{pd}.
     ##
-    ## When called with a single size argument, @code{betarnd} returns a square
+    ## When called with a single size argument, @code{tlsrnd} returns a square
     ## matrix with the dimension specified.  When called with more than one
     ## scalar argument, the first two arguments are taken as the number of rows
     ## and columns and any further arguments specify additional matrix
@@ -557,13 +699,14 @@ classdef tLocationScaleDistribution
     ##
     ## Truncate a probability distribution.
     ##
-    ## @code{@var{t} = truncate (@var{pd})} returns a probability distribution
-    ## @var{t}, which is the probability distribution @var{pd} truncated to the
-    ## specified interval with lower limit, @var{lower}, and upper limit,
-    ## @var{upper}.  If @var{pd} is fitted to data with @code{fitdist}, the
-    ## returned probability distribution @var{t} is not fitted, does not contain
-    ## any data or estimated values, and it is as it has been created with the
-    ## @var{makedist} function, but it includes the truncation interval.
+    ## @code{@var{t} = truncate (@var{pd}, @var{lower}, @var{upper})} returns a
+    ## probability distribution @var{t}, which is the probability distribution
+    ## @var{pd} truncated to the specified interval with lower limit,
+    ## @var{lower}, and upper limit, @var{upper}.  If @var{pd} is fitted to data
+    ## with @code{fitdist}, the returned probability distribution @var{t} is not
+    ## fitted, does not contain any data or estimated values, and it is as it
+    ## has been created with the @var{makedist} function, but it includes the
+    ## truncation interval.
     ##
     ## @end deftypefn
     function this = truncate (this, lower, upper)
@@ -587,7 +730,7 @@ classdef tLocationScaleDistribution
     ##
     ## Compute the variance of a probability distribution.
     ##
-    ## @code{@var{v} = var (@var{pd})} computes the standard deviation of the
+    ## @code{@var{v} = var (@var{pd})} computes the variance of the
     ## probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
@@ -671,6 +814,20 @@ function checkparams (mu, sigma, nu)
   endif
 endfunction
 
+%!demo
+%! ## Generate a data set of 5000 random samples from a t Location-Scale distribution
+%! ## with parameters mu = 0, sigma = 1, and nu = 5. Fit a t Location-Scale
+%! ## distribution to this data and plot a PDF of the fitted distribution
+%! ## superimposed on a histogram of the data.
+%!
+%! pd_fixed = makedist ("tLocationScale", "mu", 0, "sigma", 1, "nu", 5);
+%! rand ("seed", 2);
+%! data = random (pd_fixed, 5000, 1);
+%! pd_fitted = fitdist (data, "tLocationScale");
+%! plot (pd_fitted);
+%! msg = "Fitted t Location-Scale distribution with mu = %0.2f, sigma = %0.2f, nu = %0.2f";
+%! title (sprintf (msg, pd_fitted.mu, pd_fitted.sigma, pd_fitted.nu));
+
 ## Test output
 %!shared pd, t
 %! pd = tLocationScaleDistribution;
