@@ -37,7 +37,7 @@
 ## @math{NxP} matrix with @math{N} observations in @math{P} dimensional space
 ## and @var{Y} is an @math{Nx1} column vector as the dependent variable.  The
 ## information about errors of the predictions (interpolation/extrapolation) is
-## given by the covarianve matrix @var{K}.
+## given by the covariance matrix @var{K}.
 ## By default, the linear model defines the prior covariance of @var{m} as
 ## @code{@var{Sp} = 100 * eye (size (@var{X}, 2) + 1)}.  A custom prior
 ## covariance matrix can be passed as @var{Sp}, which must be a @math{P+1xP+1}
@@ -83,7 +83,7 @@ function [Yfit, Yint, varargout] = regress_gp (X, Y, Xfit, varargin)
     error ("regress_gp: X and XI must have the same number of columns.");
   endif
 
-  ## Add defauts
+  ## Add defaults
   kernel = "linear";
   Sp = 100 * eye (size (X, 2) + 1);
   theta = 5;
@@ -172,12 +172,12 @@ function [Yfit, Yint, varargout] = regress_gp (X, Y, Xfit, varargin)
     ## (1/sy^2)*A^{-1}*X*Y
     ## Then one obtains
     ## inv(X*X' + sy^2 * inv(Vp))*X*Y
-    ## Looking at the formula bloew we see that Sp = (1/sy^2)*Vp
+    ## Looking at the formula below we see that Sp = (1/sy^2)*Vp
     ## making the regression depend on only one parameter, Sp, and not two.
 
     ## Xsq = sum (X' .^ 2);
     ## [n, d] = size (X);
-    ## ￼sigma = 1/sqrt(2);
+    ## sigma = 1/sqrt(2);
     ## Ks = exp (-(Xsq' * ones (1, n) -ones (n, 1) * Xsq + 2 * X * X') / (2 * sigma ^ 2));
 
     A  = X * X' + inv (Sp);
@@ -225,7 +225,7 @@ function [Yfit, Yint, varargout] = regress_gp (X, Y, Xfit, varargin)
     Dx = pdist2 (Xfit, X) .^ 2;
     Sx = exp (-Dx / theta);
 
-    ## Caculate predictive covariance
+    ## Calculate predictive covariance
     K = inv (S);
 
     ## Calculate response output
