@@ -40,17 +40,17 @@
 ## non-singleton dimension and @var{x} and @var{y} must have the same size along
 ## all the remaining dimensions.
 ##
-## @code{vartest} treats NaNs as missing values, and ignores them.
+## @code{vartest2} treats NaNs as missing values, and ignores them.
 ##
-## @code{[@var{h}, @var{pval}] = vartest (@dots{})} returns the p-value.  That
+## @code{[@var{h}, @var{pval}] = vartest2 (@dots{})} returns the p-value.  That
 ## is the probability of observing the given result, or one more extreme, by
-## chance if the null hypothesisis true.
+## chance if the null hypothesis true.
 ##
-## @code{[@var{h}, @var{pval}, @var{ci}] = vartest (@dots{})} returns a
+## @code{[@var{h}, @var{pval}, @var{ci}] = vartest2 (@dots{})} returns a
 ## @math{100 * (1 - @var{alpha})%} confidence interval for the true ratio
 ## var(X)/var(Y).
 ##
-## @code{[@var{h}, @var{pval}, @var{ci}, @var{stats}] = vartest (@dots{})}
+## @code{[@var{h}, @var{pval}, @var{ci}, @var{stats}] = vartest2 (@dots{})}
 ## returns a structure with the following fields:
 ##
 ## @multitable @columnfractions 0.05 0.2 0.75
@@ -59,7 +59,7 @@
 ## @item @tab @qcode{df2} @tab the denominator degrees of freedom of the test
 ## @end multitable
 ##
-## @code{[@dots{}] = vartest (@dots{}, @var{name}, @var{value}), @dots{}}
+## @code{[@dots{}] = vartest2 (@dots{}, @var{name}, @var{value}), @dots{}}
 ## specifies one or more of the following name/value pairs:
 ##
 ## @multitable @columnfractions 0.05 0.2 0.75
@@ -140,7 +140,7 @@ function [h, pval, ci, stats] = vartest2 (x, y, varargin)
   x_size(dim) = 1;
   y_size(dim) = 1;
   if (! isequal (x_size, y_size))
-    error ("vartestt2: input size mismatch.");
+    error ("vartest2: input size mismatch.");
   endif
   ## Compute statistics for each sample
   [df1, x_var] = getstats(x,dim);
@@ -159,7 +159,9 @@ function [h, pval, ci, stats] = vartest2 (x, y, varargin)
                      F ./ finv (alpha / 2, df1, df2));
     endif
   elseif (strcmpi (tail, "right"))
-    pval = 1 - fcdf (F, df1, df2);
+    Ftmp = F;
+    Ftmp(Ftmp < 0) = 0;
+    pval = fcdf (1 ./ Ftmp, df2, df1);
     if (nargout > 2)
       ci = cat (dim, F .* finv (alpha, df2, df1), Inf (size (F)));
     endif
@@ -242,4 +244,24 @@ endfunction
 %! assert (stat.fstat, 0.8384, 1e-4);
 %! assert (stat.df1, 30);
 %! assert (stat.df2, 33);
+%!test
+%! load carsmall
+%! [h, pval, ci, stat] = vartest2 (MPG(Model_Year==82), MPG(Model_Year==76), ...
+%!                                 "tail", "left");
+%! assert (h, 0);
+%! assert (pval, 0.314401118135922, 1e-13);
+%! assert (ci, [0; 1.5287], 1e-4);
+%! assert (stat.fstat, 0.8384, 1e-4);
+%! assert (stat.df1, 30);
+%! assert (stat.df2, 33);
+%!test
+%! load carsmall
+%! [h, pval, ci, stat] = vartest2 (MPG(Model_Year==82), MPG(Model_Year==76), ...
+%!                                 "tail", "right");
+%! assert (h, 0);
+%! assert (pval, 0.685598881864077, 1e-13);
+%! assert (ci, [0.4643; Inf], 1e-4);
+%! assert (stat.fstat, 0.8384, 1e-4);
+%! assert (stat.df1, 30);
+%! assert (stat.df2, 33);
 
